import OCP.ShapeCustom
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.ShapeExtend
import OCP.gp
import OCP.Geom
import OCP.TopTools
import OCP.BRepTools
import OCP.TopLoc
import OCP.TopoDS
import OCP.Message
import OCP.TColgp
import OCP.ShapeBuild
import OCP.Standard
import OCP.Poly
import OCP.GeomAbs
import OCP.Geom2d
__all__  = [
"ShapeCustom",
"ShapeCustom_Modification",
"ShapeCustom_ConvertToBSpline",
"ShapeCustom_ConvertToRevolution",
"ShapeCustom_Curve",
"ShapeCustom_Curve2d",
"ShapeCustom_DirectModification",
"ShapeCustom_BSplineRestriction",
"ShapeCustom_RestrictionParameters",
"ShapeCustom_Surface",
"ShapeCustom_SweptToElementary",
"ShapeCustom_TrsfModification"
]
class ShapeCustom():
    """
    This package is intended to convert geometrical objects and topological. The modifications of one geometrical object to another (one) geometrical object are provided. The supported modifications are the following: conversion of BSpline and Bezier surfaces to analytical form, conversion of indirect elementary surfaces (with left-handed coordinate systems) into direct ones, conversion of elementary surfaces to surfaces of revolution, conversion of surface of linear extrusion, revolution, offset surface to bspline, modification of parameterization, degree, number of segments of bspline surfaces, scale the shape.
    """
    @staticmethod
    def ApplyModifier_s(S : OCP.TopoDS.TopoDS_Shape,M : OCP.BRepTools.BRepTools_Modification,context : OCP.TopTools.TopTools_DataMapOfShapeShape,MD : OCP.BRepTools.BRepTools_Modifier,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange,aReShape : OCP.ShapeBuild.ShapeBuild_ReShape=None) -> OCP.TopoDS.TopoDS_Shape: 
        """
        Applies modifier to shape and checks sharing in the case assemblies.
        """
    @staticmethod
    def BSplineRestriction_s(S : OCP.TopoDS.TopoDS_Shape,Tol3d : float,Tol2d : float,MaxDegree : int,MaxNbSegment : int,Continuity3d : OCP.GeomAbs.GeomAbs_Shape,Continuity2d : OCP.GeomAbs.GeomAbs_Shape,Degree : bool,Rational : bool,aParameters : ShapeCustom_RestrictionParameters) -> OCP.TopoDS.TopoDS_Shape: 
        """
        Returns a new shape with all surfaces, curves and pcurves which type is BSpline/Bezier or based on them converted having Degree less than <MaxDegree> or number of spans less than <NbMaxSegment> in dependence on parameter priority <Degree>. <GmaxDegree> and <GMaxSegments> are maximum possible degree and number of spans correspondingly. These values will be used in those cases when approximation with specified parameters is impossible and one of GmaxDegree or GMaxSegments is selected in dependence on priority. Note that even if approximation is impossible with <GMaxDegree> then number of spans can exceed specified <GMaxSegment> <Rational> specifies if to convert Rational BSpline/Bezier into polynomial B-Spline. If flags ConvOffSurf,ConvOffCurve3d,ConvOffCurve2d are Standard_True there are means that Offset surfaces , Offset curves 3d and Offset curves 2d are converted to BSPline correspondingly.
        """
    @staticmethod
    def ConvertToBSpline_s(S : OCP.TopoDS.TopoDS_Shape,extrMode : bool,revolMode : bool,offsetMode : bool,planeMode : bool=False) -> OCP.TopoDS.TopoDS_Shape: 
        """
        Returns a new shape with all surfaces of linear extrusion, revolution, offset, and planar surfaces converted according to flags to Geom_BSplineSurface (with same parameterisation).
        """
    @staticmethod
    def ConvertToRevolution_s(S : OCP.TopoDS.TopoDS_Shape) -> OCP.TopoDS.TopoDS_Shape: 
        """
        Returns a new shape with all elementary periodic surfaces converted to Geom_SurfaceOfRevolution
        """
    @staticmethod
    def DirectFaces_s(S : OCP.TopoDS.TopoDS_Shape) -> OCP.TopoDS.TopoDS_Shape: 
        """
        Returns a new shape without indirect surfaces.
        """
    @staticmethod
    def ScaleShape_s(S : OCP.TopoDS.TopoDS_Shape,scale : float) -> OCP.TopoDS.TopoDS_Shape: 
        """
        Returns a new shape which is scaled original
        """
    @staticmethod
    def SweptToElementary_s(S : OCP.TopoDS.TopoDS_Shape) -> OCP.TopoDS.TopoDS_Shape: 
        """
        Returns a new shape with all surfaces of revolution and linear extrusion convert to elementary periodic surfaces
        """
    def __init__(self) -> None: ...
    pass
class ShapeCustom_Modification(OCP.BRepTools.BRepTools_Modification, OCP.Standard.Standard_Transient):
    """
    A base class of Modification's from ShapeCustom. Implements message sending mechanism.A base class of Modification's from ShapeCustom. Implements message sending mechanism.A base class of Modification's from ShapeCustom. Implements message sending mechanism.
    """
    def Continuity(self,E : OCP.TopoDS.TopoDS_Edge,F1 : OCP.TopoDS.TopoDS_Face,F2 : OCP.TopoDS.TopoDS_Face,NewE : OCP.TopoDS.TopoDS_Edge,NewF1 : OCP.TopoDS.TopoDS_Face,NewF2 : OCP.TopoDS.TopoDS_Face) -> OCP.GeomAbs.GeomAbs_Shape: 
        """
        Returns the continuity of <NewE> between <NewF1> and <NewF2>. <NewE> is the new edge created from <E>. <NewF1> (resp. <NewF2>) is the new face created from <F1> (resp. <F2>).
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MsgRegistrator(self) -> OCP.ShapeExtend.ShapeExtend_BasicMsgRegistrator: 
        """
        Returns message registrator
        """
    def NewCurve(self,E : OCP.TopoDS.TopoDS_Edge,C : OCP.Geom.Geom_Curve,L : OCP.TopLoc.TopLoc_Location,Tol : float) -> bool: 
        """
        Returns true if the edge, E, has been modified. If the edge has been modified: - C is the new geometry associated with the edge, - L is its new location, and - Tol is the new tolerance. If the edge has not been modified, this function returns false, and the values of C, L and Tol are not significant.
        """
    def NewCurve2d(self,E : OCP.TopoDS.TopoDS_Edge,F : OCP.TopoDS.TopoDS_Face,NewE : OCP.TopoDS.TopoDS_Edge,NewF : OCP.TopoDS.TopoDS_Face,C : OCP.Geom2d.Geom2d_Curve,Tol : float) -> bool: 
        """
        Returns true if the edge, E, has a new curve on surface on the face, F. If a new curve exists: - C is the new geometry of the edge, - L is the new location, and - Tol is the new tolerance. NewE is the new edge created from E, and NewF is the new face created from F. If there is no new curve on the face, this function returns false, and the values of C, L and Tol are not significant.
        """
    def NewParameter(self,V : OCP.TopoDS.TopoDS_Vertex,E : OCP.TopoDS.TopoDS_Edge,P : float,Tol : float) -> bool: 
        """
        Returns true if the vertex V has a new parameter on the edge E. If a new parameter exists: - P is the parameter, and - Tol is the new tolerance. If there is no new parameter this function returns false, and the values of P and Tol are not significant.
        """
    def NewPoint(self,V : OCP.TopoDS.TopoDS_Vertex,P : OCP.gp.gp_Pnt,Tol : float) -> bool: 
        """
        Returns true if the vertex V has been modified. If V has been modified: - P is the new geometry of the vertex, and - Tol is the new tolerance. If the vertex has not been modified this function returns false, and the values of P and Tol are not significant.
        """
    def NewPolygon(self,E : OCP.TopoDS.TopoDS_Edge,P : OCP.Poly.Poly_Polygon3D) -> bool: 
        """
        Returns true if the edge has been modified according to changed polygon. If the edge has been modified: - P is a new polygon
        """
    def NewPolygonOnTriangulation(self,E : OCP.TopoDS.TopoDS_Edge,F : OCP.TopoDS.TopoDS_Face,P : OCP.Poly.Poly_PolygonOnTriangulation) -> bool: 
        """
        Returns true if the edge has been modified according to changed polygon on triangulation. If the edge has been modified: - P is a new polygon on triangulation
        """
    def NewSurface(self,F : OCP.TopoDS.TopoDS_Face,S : OCP.Geom.Geom_Surface,L : OCP.TopLoc.TopLoc_Location,Tol : float,RevWires : bool,RevFace : bool) -> bool: 
        """
        Returns true if the face, F, has been modified. If the face has been modified: - S is the new geometry of the face, - L is its new location, and - Tol is the new tolerance. The flag, RevWires, is set to true when the modification reverses the normal of the surface, (i.e. the wires have to be reversed). The flag, RevFace, is set to true if the orientation of the modified face changes in the shells which contain it. If the face has not been modified this function returns false, and the values of S, L, Tol, RevWires and RevFace are not significant.
        """
    def NewTriangulation(self,F : OCP.TopoDS.TopoDS_Face,T : OCP.Poly.Poly_Triangulation) -> bool: 
        """
        Returns true if the face has been modified according to changed triangulation. If the face has been modified: - T is a new triangulation on the face
        """
    def SendMsg(self,shape : OCP.TopoDS.TopoDS_Shape,message : OCP.Message.Message_Msg,gravity : OCP.Message.Message_Gravity=Message_Gravity.Message_Info) -> None: 
        """
        Sends a message to be attached to the shape. Calls corresponding message of message registrator.
        """
    def SetMsgRegistrator(self,msgreg : OCP.ShapeExtend.ShapeExtend_BasicMsgRegistrator) -> None: 
        """
        Sets message registrator
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class ShapeCustom_ConvertToBSpline(ShapeCustom_Modification, OCP.BRepTools.BRepTools_Modification, OCP.Standard.Standard_Transient):
    """
    implement a modification for BRepTools Modifier algorithm. Converts Surface of Linear Exctrusion, Revolution and Offset surfaces into BSpline Surface according to flags.implement a modification for BRepTools Modifier algorithm. Converts Surface of Linear Exctrusion, Revolution and Offset surfaces into BSpline Surface according to flags.implement a modification for BRepTools Modifier algorithm. Converts Surface of Linear Exctrusion, Revolution and Offset surfaces into BSpline Surface according to flags.
    """
    def Continuity(self,E : OCP.TopoDS.TopoDS_Edge,F1 : OCP.TopoDS.TopoDS_Face,F2 : OCP.TopoDS.TopoDS_Face,NewE : OCP.TopoDS.TopoDS_Edge,NewF1 : OCP.TopoDS.TopoDS_Face,NewF2 : OCP.TopoDS.TopoDS_Face) -> OCP.GeomAbs.GeomAbs_Shape: 
        """
        Returns the continuity of <NewE> between <NewF1> and <NewF2>.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MsgRegistrator(self) -> OCP.ShapeExtend.ShapeExtend_BasicMsgRegistrator: 
        """
        Returns message registrator
        """
    def NewCurve(self,E : OCP.TopoDS.TopoDS_Edge,C : OCP.Geom.Geom_Curve,L : OCP.TopLoc.TopLoc_Location,Tol : float) -> bool: 
        """
        Returns Standard_True if the edge <E> has been modified. In this case, <C> is the new geometric support of the edge, <L> the new location, <Tol> the new tolerance. Otherwise, returns Standard_False, and <C>, <L>, <Tol> are not significant.
        """
    def NewCurve2d(self,E : OCP.TopoDS.TopoDS_Edge,F : OCP.TopoDS.TopoDS_Face,NewE : OCP.TopoDS.TopoDS_Edge,NewF : OCP.TopoDS.TopoDS_Face,C : OCP.Geom2d.Geom2d_Curve,Tol : float) -> bool: 
        """
        Returns Standard_True if the edge <E> has a new curve on surface on the face <F>.In this case, <C> is the new geometric support of the edge, <L> the new location, <Tol> the new tolerance.
        """
    def NewParameter(self,V : OCP.TopoDS.TopoDS_Vertex,E : OCP.TopoDS.TopoDS_Edge,P : float,Tol : float) -> bool: 
        """
        Returns Standard_True if the Vertex <V> has a new parameter on the edge <E>. In this case, <P> is the parameter, <Tol> the new tolerance. Otherwise, returns Standard_False, and <P>, <Tol> are not significant.
        """
    def NewPoint(self,V : OCP.TopoDS.TopoDS_Vertex,P : OCP.gp.gp_Pnt,Tol : float) -> bool: 
        """
        Returns Standard_True if the vertex <V> has been modified. In this case, <P> is the new geometric support of the vertex, <Tol> the new tolerance. Otherwise, returns Standard_False, and <P>, <Tol> are not significant.
        """
    def NewPolygon(self,E : OCP.TopoDS.TopoDS_Edge,P : OCP.Poly.Poly_Polygon3D) -> bool: 
        """
        Returns true if the edge has been modified according to changed polygon. If the edge has been modified: - P is a new polygon
        """
    def NewPolygonOnTriangulation(self,E : OCP.TopoDS.TopoDS_Edge,F : OCP.TopoDS.TopoDS_Face,P : OCP.Poly.Poly_PolygonOnTriangulation) -> bool: 
        """
        Returns true if the edge has been modified according to changed polygon on triangulation. If the edge has been modified: - P is a new polygon on triangulation
        """
    def NewSurface(self,F : OCP.TopoDS.TopoDS_Face,S : OCP.Geom.Geom_Surface,L : OCP.TopLoc.TopLoc_Location,Tol : float,RevWires : bool,RevFace : bool) -> bool: 
        """
        Returns Standard_True if the face <F> has been modified. In this case, <S> is the new geometric support of the face, <L> the new location, <Tol> the new tolerance. Otherwise, returns Standard_False, and <S>, <L>, <Tol> are not significant.
        """
    def NewTriangulation(self,F : OCP.TopoDS.TopoDS_Face,T : OCP.Poly.Poly_Triangulation) -> bool: 
        """
        Returns true if the face has been modified according to changed triangulation. If the face has been modified: - T is a new triangulation on the face
        """
    def SendMsg(self,shape : OCP.TopoDS.TopoDS_Shape,message : OCP.Message.Message_Msg,gravity : OCP.Message.Message_Gravity=Message_Gravity.Message_Info) -> None: 
        """
        Sends a message to be attached to the shape. Calls corresponding message of message registrator.
        """
    def SetExtrusionMode(self,extrMode : bool) -> None: 
        """
        Sets mode for conversion of Surfaces of Linear extrusion.
        """
    def SetMsgRegistrator(self,msgreg : OCP.ShapeExtend.ShapeExtend_BasicMsgRegistrator) -> None: 
        """
        Sets message registrator
        """
    def SetOffsetMode(self,offsetMode : bool) -> None: 
        """
        Sets mode for conversion of Offset surfaces.
        """
    def SetPlaneMode(self,planeMode : bool) -> None: 
        """
        Sets mode for conversion of Plane surfaces.
        """
    def SetRevolutionMode(self,revolMode : bool) -> None: 
        """
        Sets mode for conversion of Surfaces of Revolution.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class ShapeCustom_ConvertToRevolution(ShapeCustom_Modification, OCP.BRepTools.BRepTools_Modification, OCP.Standard.Standard_Transient):
    """
    implements a modification for the BRepTools Modifier algorithm. Converts all elementary surfaces into surfaces of revolution.implements a modification for the BRepTools Modifier algorithm. Converts all elementary surfaces into surfaces of revolution.implements a modification for the BRepTools Modifier algorithm. Converts all elementary surfaces into surfaces of revolution.
    """
    def Continuity(self,E : OCP.TopoDS.TopoDS_Edge,F1 : OCP.TopoDS.TopoDS_Face,F2 : OCP.TopoDS.TopoDS_Face,NewE : OCP.TopoDS.TopoDS_Edge,NewF1 : OCP.TopoDS.TopoDS_Face,NewF2 : OCP.TopoDS.TopoDS_Face) -> OCP.GeomAbs.GeomAbs_Shape: 
        """
        Returns the continuity of <NewE> between <NewF1> and <NewF2>.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MsgRegistrator(self) -> OCP.ShapeExtend.ShapeExtend_BasicMsgRegistrator: 
        """
        Returns message registrator
        """
    def NewCurve(self,E : OCP.TopoDS.TopoDS_Edge,C : OCP.Geom.Geom_Curve,L : OCP.TopLoc.TopLoc_Location,Tol : float) -> bool: 
        """
        Returns Standard_True if the edge <E> has been modified. In this case, <C> is the new geometric support of the edge, <L> the new location, <Tol> the new tolerance. Otherwise, returns Standard_False, and <C>, <L>, <Tol> are not significant.
        """
    def NewCurve2d(self,E : OCP.TopoDS.TopoDS_Edge,F : OCP.TopoDS.TopoDS_Face,NewE : OCP.TopoDS.TopoDS_Edge,NewF : OCP.TopoDS.TopoDS_Face,C : OCP.Geom2d.Geom2d_Curve,Tol : float) -> bool: 
        """
        Returns Standard_True if the edge <E> has a new curve on surface on the face <F>.In this case, <C> is the new geometric support of the edge, <L> the new location, <Tol> the new tolerance.
        """
    def NewParameter(self,V : OCP.TopoDS.TopoDS_Vertex,E : OCP.TopoDS.TopoDS_Edge,P : float,Tol : float) -> bool: 
        """
        Returns Standard_True if the Vertex <V> has a new parameter on the edge <E>. In this case, <P> is the parameter, <Tol> the new tolerance. Otherwise, returns Standard_False, and <P>, <Tol> are not significant.
        """
    def NewPoint(self,V : OCP.TopoDS.TopoDS_Vertex,P : OCP.gp.gp_Pnt,Tol : float) -> bool: 
        """
        Returns Standard_True if the vertex <V> has been modified. In this case, <P> is the new geometric support of the vertex, <Tol> the new tolerance. Otherwise, returns Standard_False, and <P>, <Tol> are not significant.
        """
    def NewPolygon(self,E : OCP.TopoDS.TopoDS_Edge,P : OCP.Poly.Poly_Polygon3D) -> bool: 
        """
        Returns true if the edge has been modified according to changed polygon. If the edge has been modified: - P is a new polygon
        """
    def NewPolygonOnTriangulation(self,E : OCP.TopoDS.TopoDS_Edge,F : OCP.TopoDS.TopoDS_Face,P : OCP.Poly.Poly_PolygonOnTriangulation) -> bool: 
        """
        Returns true if the edge has been modified according to changed polygon on triangulation. If the edge has been modified: - P is a new polygon on triangulation
        """
    def NewSurface(self,F : OCP.TopoDS.TopoDS_Face,S : OCP.Geom.Geom_Surface,L : OCP.TopLoc.TopLoc_Location,Tol : float,RevWires : bool,RevFace : bool) -> bool: 
        """
        Returns Standard_True if the face <F> has been modified. In this case, <S> is the new geometric support of the face, <L> the new location, <Tol> the new tolerance. Otherwise, returns Standard_False, and <S>, <L>, <Tol> are not significant.
        """
    def NewTriangulation(self,F : OCP.TopoDS.TopoDS_Face,T : OCP.Poly.Poly_Triangulation) -> bool: 
        """
        Returns true if the face has been modified according to changed triangulation. If the face has been modified: - T is a new triangulation on the face
        """
    def SendMsg(self,shape : OCP.TopoDS.TopoDS_Shape,message : OCP.Message.Message_Msg,gravity : OCP.Message.Message_Gravity=Message_Gravity.Message_Info) -> None: 
        """
        Sends a message to be attached to the shape. Calls corresponding message of message registrator.
        """
    def SetMsgRegistrator(self,msgreg : OCP.ShapeExtend.ShapeExtend_BasicMsgRegistrator) -> None: 
        """
        Sets message registrator
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class ShapeCustom_Curve():
    """
    Converts BSpline curve to periodic
    """
    def ConvertToPeriodic(self,substitute : bool,preci : float=-1.0) -> OCP.Geom.Geom_Curve: 
        """
        Tries to convert the Curve to the Periodic form Returns the resulting curve Works only if the Curve is BSpline and is closed with Precision::Confusion() Else, or in case of failure, returns a Null Handle
        """
    def Init(self,C : OCP.Geom.Geom_Curve) -> None: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,C : OCP.Geom.Geom_Curve) -> None: ...
    pass
class ShapeCustom_Curve2d():
    """
    Converts curve2d to analytical form with given precision or simplify curve2d.
    """
    @staticmethod
    def ConvertToLine2d_s(theCurve : OCP.Geom2d.Geom2d_Curve,theFirstIn : float,theLastIn : float,theTolerance : float,theNewFirst : float,theNewLast : float,theDeviation : float) -> OCP.Geom2d.Geom2d_Line: 
        """
        Try to convert BSpline2d or Bezier2d to line 2d only if it is linear. Recalculate first and last parameters. Returns line2d or null curve2d.
        """
    @staticmethod
    def IsLinear_s(thePoles : OCP.TColgp.TColgp_Array1OfPnt2d,theTolerance : float,theDeviation : float) -> bool: 
        """
        Check if poleses is in the plane with given precision Returns false if no.
        """
    @staticmethod
    def SimplifyBSpline2d_s(theBSpline2d : OCP.Geom2d.Geom2d_BSplineCurve,theTolerance : float) -> bool: 
        """
        Try to remove knots from bspline where local derivatives are the same. Remove knots with given precision. Returns false if Bsplien was not modified
        """
    def __init__(self) -> None: ...
    pass
class ShapeCustom_DirectModification(ShapeCustom_Modification, OCP.BRepTools.BRepTools_Modification, OCP.Standard.Standard_Transient):
    """
    implements a modification for the BRepTools Modifier algorithm. Will redress indirect surfaces.implements a modification for the BRepTools Modifier algorithm. Will redress indirect surfaces.implements a modification for the BRepTools Modifier algorithm. Will redress indirect surfaces.
    """
    def Continuity(self,E : OCP.TopoDS.TopoDS_Edge,F1 : OCP.TopoDS.TopoDS_Face,F2 : OCP.TopoDS.TopoDS_Face,NewE : OCP.TopoDS.TopoDS_Edge,NewF1 : OCP.TopoDS.TopoDS_Face,NewF2 : OCP.TopoDS.TopoDS_Face) -> OCP.GeomAbs.GeomAbs_Shape: 
        """
        Returns the continuity of <NewE> between <NewF1> and <NewF2>.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MsgRegistrator(self) -> OCP.ShapeExtend.ShapeExtend_BasicMsgRegistrator: 
        """
        Returns message registrator
        """
    def NewCurve(self,E : OCP.TopoDS.TopoDS_Edge,C : OCP.Geom.Geom_Curve,L : OCP.TopLoc.TopLoc_Location,Tol : float) -> bool: 
        """
        Returns Standard_True if the edge <E> has been modified. In this case, <C> is the new geometric support of the edge, <L> the new location, <Tol> the new tolerance. Otherwise, returns Standard_False, and <C>, <L>, <Tol> are not significant.
        """
    def NewCurve2d(self,E : OCP.TopoDS.TopoDS_Edge,F : OCP.TopoDS.TopoDS_Face,NewE : OCP.TopoDS.TopoDS_Edge,NewF : OCP.TopoDS.TopoDS_Face,C : OCP.Geom2d.Geom2d_Curve,Tol : float) -> bool: 
        """
        Returns Standard_True if the edge <E> has a new curve on surface on the face <F>.In this case, <C> is the new geometric support of the edge, <L> the new location, <Tol> the new tolerance.
        """
    def NewParameter(self,V : OCP.TopoDS.TopoDS_Vertex,E : OCP.TopoDS.TopoDS_Edge,P : float,Tol : float) -> bool: 
        """
        Returns Standard_True if the Vertex <V> has a new parameter on the edge <E>. In this case, <P> is the parameter, <Tol> the new tolerance. Otherwise, returns Standard_False, and <P>, <Tol> are not significant.
        """
    def NewPoint(self,V : OCP.TopoDS.TopoDS_Vertex,P : OCP.gp.gp_Pnt,Tol : float) -> bool: 
        """
        Returns Standard_True if the vertex <V> has been modified. In this case, <P> is the new geometric support of the vertex, <Tol> the new tolerance. Otherwise, returns Standard_False, and <P>, <Tol> are not significant.
        """
    def NewPolygon(self,E : OCP.TopoDS.TopoDS_Edge,P : OCP.Poly.Poly_Polygon3D) -> bool: 
        """
        Returns true if the edge has been modified according to changed polygon. If the edge has been modified: - P is a new polygon
        """
    def NewPolygonOnTriangulation(self,E : OCP.TopoDS.TopoDS_Edge,F : OCP.TopoDS.TopoDS_Face,P : OCP.Poly.Poly_PolygonOnTriangulation) -> bool: 
        """
        Returns true if the edge has been modified according to changed polygon on triangulation. If the edge has been modified: - P is a new polygon on triangulation
        """
    def NewSurface(self,F : OCP.TopoDS.TopoDS_Face,S : OCP.Geom.Geom_Surface,L : OCP.TopLoc.TopLoc_Location,Tol : float,RevWires : bool,RevFace : bool) -> bool: 
        """
        Returns Standard_True if the face <F> has been modified. In this case, <S> is the new geometric support of the face, <L> the new location, <Tol> the new tolerance. Otherwise, returns Standard_False, and <S>, <L>, <Tol> are not significant.
        """
    def NewTriangulation(self,F : OCP.TopoDS.TopoDS_Face,T : OCP.Poly.Poly_Triangulation) -> bool: 
        """
        Returns true if the face has been modified according to changed triangulation. If the face has been modified: - T is a new triangulation on the face
        """
    def SendMsg(self,shape : OCP.TopoDS.TopoDS_Shape,message : OCP.Message.Message_Msg,gravity : OCP.Message.Message_Gravity=Message_Gravity.Message_Info) -> None: 
        """
        Sends a message to be attached to the shape. Calls corresponding message of message registrator.
        """
    def SetMsgRegistrator(self,msgreg : OCP.ShapeExtend.ShapeExtend_BasicMsgRegistrator) -> None: 
        """
        Sets message registrator
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class ShapeCustom_BSplineRestriction(ShapeCustom_Modification, OCP.BRepTools.BRepTools_Modification, OCP.Standard.Standard_Transient):
    """
    this tool intended for approximation surfaces, curves and pcurves with specified degree , max number of segments, tolerance 2d, tolerance 3d. Specified continuity can be reduced if approximation with specified continuity was not done.this tool intended for approximation surfaces, curves and pcurves with specified degree , max number of segments, tolerance 2d, tolerance 3d. Specified continuity can be reduced if approximation with specified continuity was not done.this tool intended for approximation surfaces, curves and pcurves with specified degree , max number of segments, tolerance 2d, tolerance 3d. Specified continuity can be reduced if approximation with specified continuity was not done.
    """
    def Continuity(self,E : OCP.TopoDS.TopoDS_Edge,F1 : OCP.TopoDS.TopoDS_Face,F2 : OCP.TopoDS.TopoDS_Face,NewE : OCP.TopoDS.TopoDS_Edge,NewF1 : OCP.TopoDS.TopoDS_Face,NewF2 : OCP.TopoDS.TopoDS_Face) -> OCP.GeomAbs.GeomAbs_Shape: ...
    def ConvertCurve(self,aCurve : OCP.Geom.Geom_Curve,C : OCP.Geom.Geom_Curve,IsConvert : bool,First : float,Last : float,TolCur : float,IsOf : bool=True) -> bool: 
        """
        Returns Standard_True if the curve has been modified. if flag IsOf equals Standard_True Offset curves are approximated to Offset if Standard_False to BSpline
        """
    def ConvertCurve2d(self,aCurve : OCP.Geom2d.Geom2d_Curve,C : OCP.Geom2d.Geom2d_Curve,IsConvert : bool,First : float,Last : float,TolCur : float,IsOf : bool=True) -> bool: 
        """
        Returns Standard_True if the pcurve has been modified. if flag IsOf equals Standard_True Offset pcurves are approximated to Offset if Standard_False to BSpline
        """
    def ConvertSurface(self,aSurface : OCP.Geom.Geom_Surface,S : OCP.Geom.Geom_Surface,UF : float,UL : float,VF : float,VL : float,IsOf : bool=True) -> bool: 
        """
        Returns Standard_True if the surface has been modified. if flag IsOf equals Standard_True Offset surfaces are approximated to Offset if Standard_False to BSpline
        """
    def Curve2dError(self) -> float: 
        """
        Returns error for approximation curve2d.

        Returns error for approximation curve2d.
        """
    def Curve3dError(self) -> float: 
        """
        Returns error for approximation curve3d.

        Returns error for approximation curve3d.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def GetRestrictionParameters(self) -> ShapeCustom_RestrictionParameters: 
        """
        Returns the container of modes which defines what geometry should be converted to BSplines.

        Returns the container of modes which defines what geometry should be converted to BSplines.
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MaxErrors(self,aCurve3dErr : float,aCurve2dErr : float) -> float: 
        """
        Returns error for approximation surface, curve3d and curve2d.
        """
    def MsgRegistrator(self) -> OCP.ShapeExtend.ShapeExtend_BasicMsgRegistrator: 
        """
        Returns message registrator
        """
    def NbOfSpan(self) -> int: 
        """
        Returns number for approximation surface, curve3d and curve2d.
        """
    def NewCurve(self,E : OCP.TopoDS.TopoDS_Edge,C : OCP.Geom.Geom_Curve,L : OCP.TopLoc.TopLoc_Location,Tol : float) -> bool: 
        """
        Returns Standard_True if curve from the edge <E> has been modified. In this case, <C> is the new geometric support of the edge, <L> the new location, <Tol> the new tolerance. Otherwise, returns Standard_True if Surface is modified or one of pcurves of edge is modified. In this case C is copy of geometric support of the edge. In other cases returns Standard_False, and <C>, <L>, <Tol> are not significant.
        """
    def NewCurve2d(self,E : OCP.TopoDS.TopoDS_Edge,F : OCP.TopoDS.TopoDS_Face,NewE : OCP.TopoDS.TopoDS_Edge,NewF : OCP.TopoDS.TopoDS_Face,C : OCP.Geom2d.Geom2d_Curve,Tol : float) -> bool: 
        """
        Returns Standard_True if the edge <E> has been modified. In this case,if curve on the surface is modified, <C> is the new geometric support of the edge, <L> the new location, <Tol> the new tolerance. If curve on the surface is not modified C is copy curve on surface from the edge <E>.
        """
    def NewParameter(self,V : OCP.TopoDS.TopoDS_Vertex,E : OCP.TopoDS.TopoDS_Edge,P : float,Tol : float) -> bool: ...
    def NewPoint(self,V : OCP.TopoDS.TopoDS_Vertex,P : OCP.gp.gp_Pnt,Tol : float) -> bool: ...
    def NewPolygon(self,E : OCP.TopoDS.TopoDS_Edge,P : OCP.Poly.Poly_Polygon3D) -> bool: 
        """
        Returns true if the edge has been modified according to changed polygon. If the edge has been modified: - P is a new polygon
        """
    def NewPolygonOnTriangulation(self,E : OCP.TopoDS.TopoDS_Edge,F : OCP.TopoDS.TopoDS_Face,P : OCP.Poly.Poly_PolygonOnTriangulation) -> bool: 
        """
        Returns true if the edge has been modified according to changed polygon on triangulation. If the edge has been modified: - P is a new polygon on triangulation
        """
    def NewSurface(self,F : OCP.TopoDS.TopoDS_Face,S : OCP.Geom.Geom_Surface,L : OCP.TopLoc.TopLoc_Location,Tol : float,RevWires : bool,RevFace : bool) -> bool: 
        """
        Returns Standard_True if the face <F> has been modified. In this case, <S> is the new geometric support of the face, <L> the new location,<Tol> the new tolerance.<RevWires> has to be set to Standard_True when the modification reverses the normal of the surface.(the wires have to be reversed). <RevFace> has to be set to Standard_True if the orientation of the modified face changes in the shells which contain it.
        """
    def NewTriangulation(self,F : OCP.TopoDS.TopoDS_Face,T : OCP.Poly.Poly_Triangulation) -> bool: 
        """
        Returns true if the face has been modified according to changed triangulation. If the face has been modified: - T is a new triangulation on the face
        """
    def SendMsg(self,shape : OCP.TopoDS.TopoDS_Shape,message : OCP.Message.Message_Msg,gravity : OCP.Message.Message_Gravity=Message_Gravity.Message_Info) -> None: 
        """
        Sends a message to be attached to the shape. Calls corresponding message of message registrator.
        """
    def SetContinuity2d(self,Continuity2d : OCP.GeomAbs.GeomAbs_Shape) -> None: 
        """
        Sets continuity3d for approximation curve2d.

        Sets continuity3d for approximation curve2d.
        """
    def SetContinuity3d(self,Continuity3d : OCP.GeomAbs.GeomAbs_Shape) -> None: 
        """
        Sets continuity3d for approximation curve3d and surface.

        Sets continuity3d for approximation curve3d and surface.
        """
    def SetConvRational(self,Rational : bool) -> None: 
        """
        Sets flag for define if rational BSpline or Bezier is converted to polynomial. If Rational is True approximation for rational BSpline and Bezier is made to polynomial even if degree is less then MaxDegree and number of spans is less then specified MaxNbSegment.

        Sets flag for define if rational BSpline or Bezier is converted to polynomial. If Rational is True approximation for rational BSpline and Bezier is made to polynomial even if degree is less then MaxDegree and number of spans is less then specified MaxNbSegment.
        """
    def SetMaxDegree(self,MaxDegree : int) -> None: 
        """
        Sets max degree for approximation.

        Sets max degree for approximation.
        """
    def SetMaxNbSegments(self,MaxNbSegments : int) -> None: 
        """
        Sets max number of segments for approximation.

        Sets max number of segments for approximation.
        """
    def SetMsgRegistrator(self,msgreg : OCP.ShapeExtend.ShapeExtend_BasicMsgRegistrator) -> None: 
        """
        Sets message registrator
        """
    def SetPriority(self,Degree : bool) -> None: 
        """
        Sets priority for approximation curves and surface. If Degree is True approximation is made with degree less then specified MaxDegree at the expense of number of spanes. If Degree is False approximation is made with number of spans less then specified MaxNbSegment at the expense of specified MaxDegree.

        Sets priority for approximation curves and surface. If Degree is True approximation is made with degree less then specified MaxDegree at the expense of number of spanes. If Degree is False approximation is made with number of spans less then specified MaxNbSegment at the expense of specified MaxDegree.
        """
    def SetRestrictionParameters(self,aModes : ShapeCustom_RestrictionParameters) -> None: 
        """
        Sets the container of modes which defines what geometry should be converted to BSplines.

        Sets the container of modes which defines what geometry should be converted to BSplines.
        """
    def SetTol2d(self,Tol2d : float) -> None: 
        """
        Sets tolerance of approximation for curve2d

        Sets tolerance of approximation for curve2d
        """
    def SetTol3d(self,Tol3d : float) -> None: 
        """
        Sets tolerance of approximation for curve3d and surface

        Sets tolerance of approximation for curve3d and surface
        """
    def SurfaceError(self) -> float: 
        """
        Returns error for approximation surface.

        Returns error for approximation surface.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,anApproxSurfaceFlag : bool,anApproxCurve3dFlag : bool,anApproxCurve2dFlag : bool,aTol3d : float,aTol2d : float,aContinuity3d : OCP.GeomAbs.GeomAbs_Shape,aContinuity2d : OCP.GeomAbs.GeomAbs_Shape,aMaxDegree : int,aNbMaxSeg : int,Degree : bool,Rational : bool) -> None: ...
    @overload
    def __init__(self,anApproxSurfaceFlag : bool,anApproxCurve3dFlag : bool,anApproxCurve2dFlag : bool,aTol3d : float,aTol2d : float,aContinuity3d : OCP.GeomAbs.GeomAbs_Shape,aContinuity2d : OCP.GeomAbs.GeomAbs_Shape,aMaxDegree : int,aNbMaxSeg : int,Degree : bool,Rational : bool,aModes : ShapeCustom_RestrictionParameters) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    @property
    def ModifyApproxCurve2dFlag(self) -> bool:
        """
        :type: bool
        """
    @ModifyApproxCurve2dFlag.setter
    def ModifyApproxCurve2dFlag(self, arg1: bool) -> None:
        pass
    @property
    def ModifyApproxCurve3dFlag(self) -> bool:
        """
        :type: bool
        """
    @ModifyApproxCurve3dFlag.setter
    def ModifyApproxCurve3dFlag(self, arg1: bool) -> None:
        pass
    @property
    def ModifyApproxSurfaceFlag(self) -> bool:
        """
        :type: bool
        """
    @ModifyApproxSurfaceFlag.setter
    def ModifyApproxSurfaceFlag(self, arg1: bool) -> None:
        pass
    pass
class ShapeCustom_RestrictionParameters(OCP.Standard.Standard_Transient):
    """
    This class is axuluary tool which contains parameters for BSplineRestriction class.This class is axuluary tool which contains parameters for BSplineRestriction class.This class is axuluary tool which contains parameters for BSplineRestriction class.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    @property
    def ConvertBezierSurf(self) -> bool:
        """
        Sets flag for define if Bezier surface converted to BSpline surface.

        :type: bool
        """
    @ConvertBezierSurf.setter
    def ConvertBezierSurf(self, arg1: bool) -> None:
        """
        Sets flag for define if Bezier surface converted to BSpline surface.
        """
    @property
    def ConvertConicalSurf(self) -> bool:
        """
        Sets flag for define if conical surface converted to BSpline surface.

        :type: bool
        """
    @ConvertConicalSurf.setter
    def ConvertConicalSurf(self, arg1: bool) -> None:
        """
        Sets flag for define if conical surface converted to BSpline surface.
        """
    @property
    def ConvertCurve2d(self) -> bool:
        """
        :type: bool
        """
    @ConvertCurve2d.setter
    def ConvertCurve2d(self, arg1: bool) -> None:
        pass
    @property
    def ConvertCurve3d(self) -> bool:
        """
        Sets flag for define if 3d curve converted to BSpline curve.

        :type: bool
        """
    @ConvertCurve3d.setter
    def ConvertCurve3d(self, arg1: bool) -> None:
        """
        Sets flag for define if 3d curve converted to BSpline curve.
        """
    @property
    def ConvertCylindricalSurf(self) -> bool:
        """
        Sets flag for define if cylindrical surface converted to BSpline surface.

        :type: bool
        """
    @ConvertCylindricalSurf.setter
    def ConvertCylindricalSurf(self, arg1: bool) -> None:
        """
        Sets flag for define if cylindrical surface converted to BSpline surface.
        """
    @property
    def ConvertExtrusionSurf(self) -> bool:
        """
        Sets flag for define if surface of LinearExtrusion converted to BSpline surface.

        :type: bool
        """
    @ConvertExtrusionSurf.setter
    def ConvertExtrusionSurf(self, arg1: bool) -> None:
        """
        Sets flag for define if surface of LinearExtrusion converted to BSpline surface.
        """
    @property
    def ConvertOffsetCurv2d(self) -> bool:
        """
        :type: bool
        """
    @ConvertOffsetCurv2d.setter
    def ConvertOffsetCurv2d(self, arg1: bool) -> None:
        pass
    @property
    def ConvertOffsetCurv3d(self) -> bool:
        """
        Sets flag for define if Offset curve3d converted to BSpline surface.

        :type: bool
        """
    @ConvertOffsetCurv3d.setter
    def ConvertOffsetCurv3d(self, arg1: bool) -> None:
        """
        Sets flag for define if Offset curve3d converted to BSpline surface.
        """
    @property
    def ConvertOffsetSurf(self) -> bool:
        """
        Sets flag for define if Offset surface converted to BSpline surface.

        :type: bool
        """
    @ConvertOffsetSurf.setter
    def ConvertOffsetSurf(self, arg1: bool) -> None:
        """
        Sets flag for define if Offset surface converted to BSpline surface.
        """
    @property
    def ConvertPlane(self) -> bool:
        """
        Sets flag for define if Plane converted to BSpline surface.

        :type: bool
        """
    @ConvertPlane.setter
    def ConvertPlane(self, arg1: bool) -> None:
        """
        Sets flag for define if Plane converted to BSpline surface.
        """
    @property
    def ConvertRevolutionSurf(self) -> bool:
        """
        Sets flag for define if surface of Revolution converted to BSpline surface.

        :type: bool
        """
    @ConvertRevolutionSurf.setter
    def ConvertRevolutionSurf(self, arg1: bool) -> None:
        """
        Sets flag for define if surface of Revolution converted to BSpline surface.
        """
    @property
    def ConvertSphericalSurf(self) -> bool:
        """
        Sets flag for define if spherical surface converted to BSpline surface.

        :type: bool
        """
    @ConvertSphericalSurf.setter
    def ConvertSphericalSurf(self, arg1: bool) -> None:
        """
        Sets flag for define if spherical surface converted to BSpline surface.
        """
    @property
    def ConvertToroidalSurf(self) -> bool:
        """
        Sets flag for define if toroidal surface converted to BSpline surface.

        :type: bool
        """
    @ConvertToroidalSurf.setter
    def ConvertToroidalSurf(self, arg1: bool) -> None:
        """
        Sets flag for define if toroidal surface converted to BSpline surface.
        """
    @property
    def GMaxDegree(self) -> int:
        """
        :type: int
        """
    @GMaxDegree.setter
    def GMaxDegree(self, arg1: int) -> None:
        pass
    @property
    def GMaxSeg(self) -> int:
        """
        :type: int
        """
    @GMaxSeg.setter
    def GMaxSeg(self, arg1: int) -> None:
        pass
    @property
    def SegmentSurfaceMode(self) -> bool:
        """
        Sets Segment mode for surface. If Segment is True surface is approximated in the bondaries of face lying on this surface.

        :type: bool
        """
    @SegmentSurfaceMode.setter
    def SegmentSurfaceMode(self, arg1: bool) -> None:
        """
        Sets Segment mode for surface. If Segment is True surface is approximated in the bondaries of face lying on this surface.
        """
    pass
class ShapeCustom_Surface():
    """
    Converts a surface to the analytical form with given precision. Conversion is done only the surface is bspline of bezier and this can be approximated by some analytical surface with that precision.
    """
    def ConvertToAnalytical(self,tol : float,substitute : bool) -> OCP.Geom.Geom_Surface: 
        """
        Tries to convert the Surface to an Analytic form Returns the result Works only if the Surface is BSpline or Bezier. Else, or in case of failure, returns a Null Handle
        """
    def ConvertToPeriodic(self,substitute : bool,preci : float=-1.0) -> OCP.Geom.Geom_Surface: 
        """
        Tries to convert the Surface to the Periodic form Returns the resulting surface Works only if the Surface is BSpline and is closed with Precision::Confusion() Else, or in case of failure, returns a Null Handle
        """
    def Gap(self) -> float: 
        """
        Returns maximal deviation of converted surface from the original one computed by last call to ConvertToAnalytical

        Returns maximal deviation of converted surface from the original one computed by last call to ConvertToAnalytical
        """
    def Init(self,S : OCP.Geom.Geom_Surface) -> None: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,S : OCP.Geom.Geom_Surface) -> None: ...
    pass
class ShapeCustom_SweptToElementary(ShapeCustom_Modification, OCP.BRepTools.BRepTools_Modification, OCP.Standard.Standard_Transient):
    """
    implements a modification for the BRepTools Modifier algorithm. Converts all elementary surfaces into surfaces of revolution.implements a modification for the BRepTools Modifier algorithm. Converts all elementary surfaces into surfaces of revolution.implements a modification for the BRepTools Modifier algorithm. Converts all elementary surfaces into surfaces of revolution.
    """
    def Continuity(self,E : OCP.TopoDS.TopoDS_Edge,F1 : OCP.TopoDS.TopoDS_Face,F2 : OCP.TopoDS.TopoDS_Face,NewE : OCP.TopoDS.TopoDS_Edge,NewF1 : OCP.TopoDS.TopoDS_Face,NewF2 : OCP.TopoDS.TopoDS_Face) -> OCP.GeomAbs.GeomAbs_Shape: 
        """
        Returns the continuity of <NewE> between <NewF1> and <NewF2>.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MsgRegistrator(self) -> OCP.ShapeExtend.ShapeExtend_BasicMsgRegistrator: 
        """
        Returns message registrator
        """
    def NewCurve(self,E : OCP.TopoDS.TopoDS_Edge,C : OCP.Geom.Geom_Curve,L : OCP.TopLoc.TopLoc_Location,Tol : float) -> bool: 
        """
        Returns Standard_True if the edge <E> has been modified. In this case, <C> is the new geometric support of the edge, <L> the new location, <Tol> the new tolerance. Otherwise, returns Standard_False, and <C>, <L>, <Tol> are not significant.
        """
    def NewCurve2d(self,E : OCP.TopoDS.TopoDS_Edge,F : OCP.TopoDS.TopoDS_Face,NewE : OCP.TopoDS.TopoDS_Edge,NewF : OCP.TopoDS.TopoDS_Face,C : OCP.Geom2d.Geom2d_Curve,Tol : float) -> bool: 
        """
        Returns Standard_True if the edge <E> has a new curve on surface on the face <F>.In this case, <C> is the new geometric support of the edge, <L> the new location, <Tol> the new tolerance.
        """
    def NewParameter(self,V : OCP.TopoDS.TopoDS_Vertex,E : OCP.TopoDS.TopoDS_Edge,P : float,Tol : float) -> bool: 
        """
        Returns Standard_True if the Vertex <V> has a new parameter on the edge <E>. In this case, <P> is the parameter, <Tol> the new tolerance. Otherwise, returns Standard_False, and <P>, <Tol> are not significant.
        """
    def NewPoint(self,V : OCP.TopoDS.TopoDS_Vertex,P : OCP.gp.gp_Pnt,Tol : float) -> bool: 
        """
        Returns Standard_True if the vertex <V> has been modified. In this case, <P> is the new geometric support of the vertex, <Tol> the new tolerance. Otherwise, returns Standard_False, and <P>, <Tol> are not significant.
        """
    def NewPolygon(self,E : OCP.TopoDS.TopoDS_Edge,P : OCP.Poly.Poly_Polygon3D) -> bool: 
        """
        Returns true if the edge has been modified according to changed polygon. If the edge has been modified: - P is a new polygon
        """
    def NewPolygonOnTriangulation(self,E : OCP.TopoDS.TopoDS_Edge,F : OCP.TopoDS.TopoDS_Face,P : OCP.Poly.Poly_PolygonOnTriangulation) -> bool: 
        """
        Returns true if the edge has been modified according to changed polygon on triangulation. If the edge has been modified: - P is a new polygon on triangulation
        """
    def NewSurface(self,F : OCP.TopoDS.TopoDS_Face,S : OCP.Geom.Geom_Surface,L : OCP.TopLoc.TopLoc_Location,Tol : float,RevWires : bool,RevFace : bool) -> bool: 
        """
        Returns Standard_True if the face <F> has been modified. In this case, <S> is the new geometric support of the face, <L> the new location, <Tol> the new tolerance. Otherwise, returns Standard_False, and <S>, <L>, <Tol> are not significant.
        """
    def NewTriangulation(self,F : OCP.TopoDS.TopoDS_Face,T : OCP.Poly.Poly_Triangulation) -> bool: 
        """
        Returns true if the face has been modified according to changed triangulation. If the face has been modified: - T is a new triangulation on the face
        """
    def SendMsg(self,shape : OCP.TopoDS.TopoDS_Shape,message : OCP.Message.Message_Msg,gravity : OCP.Message.Message_Gravity=Message_Gravity.Message_Info) -> None: 
        """
        Sends a message to be attached to the shape. Calls corresponding message of message registrator.
        """
    def SetMsgRegistrator(self,msgreg : OCP.ShapeExtend.ShapeExtend_BasicMsgRegistrator) -> None: 
        """
        Sets message registrator
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class ShapeCustom_TrsfModification(OCP.BRepTools.BRepTools_TrsfModification, OCP.BRepTools.BRepTools_Modification, OCP.Standard.Standard_Transient):
    """
    Complements BRepTools_TrsfModification to provide reversible scaling regarding tolerances. Uses actual tolerances (attached to the shapes) not ones returned by BRep_Tool::Tolerance to work with tolerances lower than Precision::Confusion.Complements BRepTools_TrsfModification to provide reversible scaling regarding tolerances. Uses actual tolerances (attached to the shapes) not ones returned by BRep_Tool::Tolerance to work with tolerances lower than Precision::Confusion.Complements BRepTools_TrsfModification to provide reversible scaling regarding tolerances. Uses actual tolerances (attached to the shapes) not ones returned by BRep_Tool::Tolerance to work with tolerances lower than Precision::Confusion.
    """
    def Continuity(self,E : OCP.TopoDS.TopoDS_Edge,F1 : OCP.TopoDS.TopoDS_Face,F2 : OCP.TopoDS.TopoDS_Face,NewE : OCP.TopoDS.TopoDS_Edge,NewF1 : OCP.TopoDS.TopoDS_Face,NewF2 : OCP.TopoDS.TopoDS_Face) -> OCP.GeomAbs.GeomAbs_Shape: 
        """
        Returns the continuity of <NewE> between <NewF1> and <NewF2>.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def NewCurve(self,E : OCP.TopoDS.TopoDS_Edge,C : OCP.Geom.Geom_Curve,L : OCP.TopLoc.TopLoc_Location,Tol : float) -> bool: 
        """
        Calls inherited method. Sets <Tol> as actual tolerance of <E> multiplied with scale factor.
        """
    def NewCurve2d(self,E : OCP.TopoDS.TopoDS_Edge,F : OCP.TopoDS.TopoDS_Face,NewE : OCP.TopoDS.TopoDS_Edge,NewF : OCP.TopoDS.TopoDS_Face,C : OCP.Geom2d.Geom2d_Curve,Tol : float) -> bool: 
        """
        Calls inherited method. Sets <Tol> as actual tolerance of <E> multiplied with scale factor.
        """
    def NewParameter(self,V : OCP.TopoDS.TopoDS_Vertex,E : OCP.TopoDS.TopoDS_Edge,P : float,Tol : float) -> bool: 
        """
        Calls inherited method. Sets <Tol> as actual tolerance of <V> multiplied with scale factor.
        """
    def NewPoint(self,V : OCP.TopoDS.TopoDS_Vertex,P : OCP.gp.gp_Pnt,Tol : float) -> bool: 
        """
        Calls inherited method. Sets <Tol> as actual tolerance of <V> multiplied with scale factor.
        """
    def NewPolygon(self,E : OCP.TopoDS.TopoDS_Edge,P : OCP.Poly.Poly_Polygon3D) -> bool: 
        """
        Returns true if the edge has been modified according to changed polygon. If the edge has been modified: - P is a new polygon
        """
    def NewPolygonOnTriangulation(self,E : OCP.TopoDS.TopoDS_Edge,F : OCP.TopoDS.TopoDS_Face,P : OCP.Poly.Poly_PolygonOnTriangulation) -> bool: 
        """
        Returns true if the edge has been modified according to changed polygon on triangulation. If the edge has been modified: - P is a new polygon on triangulation
        """
    def NewSurface(self,F : OCP.TopoDS.TopoDS_Face,S : OCP.Geom.Geom_Surface,L : OCP.TopLoc.TopLoc_Location,Tol : float,RevWires : bool,RevFace : bool) -> bool: 
        """
        Calls inherited method. Sets <Tol> as actual tolerance of <F> multiplied with scale factor.
        """
    def NewTriangulation(self,F : OCP.TopoDS.TopoDS_Face,T : OCP.Poly.Poly_Triangulation) -> bool: 
        """
        Returns true if the face has been modified according to changed triangulation. If the face has been modified: - T is a new triangulation on the face
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Trsf(self) -> OCP.gp.gp_Trsf: 
        """
        Provides access to the gp_Trsf associated with this modification. The transformation can be changed.
        """
    def __init__(self,T : OCP.gp.gp_Trsf) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    @property
    def IsCopyMesh(self) -> bool:
        """
        Sets a flag to indicate the need to copy mesh.

        :type: bool
        """
    @IsCopyMesh.setter
    def IsCopyMesh(self, arg1: bool) -> None:
        """
        Sets a flag to indicate the need to copy mesh.
        """
    pass



import OCP.StdLPersistent
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.TCollection
import OCP.StdObjMgt
import OCP.TDocStd
import OCP.Standard
import OCP.TFunction
import OCP.TDF
import OCP.TDataStd
__all__  = [
"StdLPersistent",
"StdLPersistent_Collection",
"StdLPersistent_Data",
"StdLPersistent_Dependency",
"StdLPersistent_Document",
"StdLPersistent_Function",
"StdLPersistent_HArray1",
"StdLPersistent_HArray1OfPersistent",
"StdLPersistent_HArray2",
"StdLPersistent_HArray2OfPersistent",
"StdLPersistent_HString",
"StdLPersistent_NamedData",
"StdLPersistent_Real",
"StdLPersistent_TreeNode",
"StdLPersistent_Value",
"StdLPersistent_Variable",
"StdLPersistent_Void",
"StdLPersistent_XLink"
]
class StdLPersistent():
    @staticmethod
    def BindTypes_s(theMap : OCP.StdObjMgt.StdObjMgt_MapOfInstantiators) -> None: 
        """
        Register types.
        """
    def __init__(self) -> None: ...
    pass
class StdLPersistent_Collection():
    def __init__(self) -> None: ...
    pass
class StdLPersistent_Data(OCP.StdObjMgt.StdObjMgt_Persistent, OCP.Standard.Standard_Transient):
    def AsciiString(self) -> OCP.TCollection.TCollection_HAsciiString: 
        """
        Get referenced ASCII string (to be overridden by ASCII string class; returns a null handle by default for other classes).
        """
    def CreateAttribute(self) -> OCP.TDF.TDF_Attribute: 
        """
        Create an empty transient attribute (to be overridden by attribute classes; does nothing and returns a null handle by default for other classes).
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: 
        """
        Returns a type descriptor about this object.
        """
    def ExtString(self) -> OCP.TCollection.TCollection_HExtendedString: 
        """
        Get referenced extended string (to be overridden by extended string class; returns a null handle by default for other classes).
        """
    def GetAttribute(self) -> OCP.TDF.TDF_Attribute: 
        """
        Get transient attribute for the persistent data (to be overridden by attribute classes; returns a null handle by default for non-attribute classes).
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def Import(self) -> OCP.TDF.TDF_Data: 
        """
        Import transient data from the persistent data.
        """
    def ImportAttribute(self) -> None: 
        """
        Import transient attribute from the persistent data (to be overridden by attribute classes; does nothing by default for non-attribute classes).
        """
    def ImportDocument(self,theDocument : OCP.TDocStd.TDocStd_Document) -> None: 
        """
        Import transient document from the persistent data (to be overridden by document class; does nothing by default for other classes).
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Label(self,theDF : OCP.TDF.TDF_Data) -> OCP.TDF.TDF_Label: 
        """
        Get a label expressed by referenced extended string (to be overridden by extended string class; returns a null label by default for other classes).
        """
    def PChildren(self,theChildren : Any) -> None: 
        """
        Gets persistent child objects
        """
    def PName(self) -> str: 
        """
        Returns persistent type name
        """
    def Read(self,theReadData : OCP.StdObjMgt.StdObjMgt_ReadData) -> None: 
        """
        Read persistent data from a file.
        """
    @overload
    def RefNum(self) -> int: 
        """
        Returns the object reference number

        Sets an object reference number
        """
    @overload
    def RefNum(self,theRefNum : int) -> None: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    @overload
    def TypeNum(self) -> int: 
        """
        Returns the assigned persistent type number

        Assigns a persistent type number to the object
        """
    @overload
    def TypeNum(self,theTypeNum : int) -> None: ...
    def Write(self,theWriteData : OCP.StdObjMgt.StdObjMgt_WriteData) -> None: 
        """
        Write persistent data to a file.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: 
        """
        Returns type descriptor of Standard_Transient class
        """
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class StdLPersistent_Dependency():
    def __init__(self) -> None: ...
    pass
class StdLPersistent_Document(OCP.StdObjMgt.StdObjMgt_Persistent, OCP.Standard.Standard_Transient):
    def AsciiString(self) -> OCP.TCollection.TCollection_HAsciiString: 
        """
        Get referenced ASCII string (to be overridden by ASCII string class; returns a null handle by default for other classes).
        """
    def CreateAttribute(self) -> OCP.TDF.TDF_Attribute: 
        """
        Create an empty transient attribute (to be overridden by attribute classes; does nothing and returns a null handle by default for other classes).
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: 
        """
        Returns a type descriptor about this object.
        """
    def ExtString(self) -> OCP.TCollection.TCollection_HExtendedString: 
        """
        Get referenced extended string (to be overridden by extended string class; returns a null handle by default for other classes).
        """
    def GetAttribute(self) -> OCP.TDF.TDF_Attribute: 
        """
        Get transient attribute for the persistent data (to be overridden by attribute classes; returns a null handle by default for non-attribute classes).
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def ImportAttribute(self) -> None: 
        """
        Import transient attribute from the persistent data (to be overridden by attribute classes; does nothing by default for non-attribute classes).
        """
    def ImportDocument(self,theDocument : OCP.TDocStd.TDocStd_Document) -> None: 
        """
        Import transient document from the persistent data.
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Label(self,theDF : OCP.TDF.TDF_Data) -> OCP.TDF.TDF_Label: 
        """
        Get a label expressed by referenced extended string (to be overridden by extended string class; returns a null label by default for other classes).
        """
    def PChildren(self,arg0 : Any) -> None: 
        """
        Gets persistent child objects
        """
    def PName(self) -> str: 
        """
        Returns persistent type name
        """
    def Read(self,theReadData : OCP.StdObjMgt.StdObjMgt_ReadData) -> None: 
        """
        Read persistent data from a file.
        """
    @overload
    def RefNum(self) -> int: 
        """
        Returns the object reference number

        Sets an object reference number
        """
    @overload
    def RefNum(self,theRefNum : int) -> None: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    @overload
    def TypeNum(self) -> int: 
        """
        Returns the assigned persistent type number

        Assigns a persistent type number to the object
        """
    @overload
    def TypeNum(self,theTypeNum : int) -> None: ...
    def Write(self,theWriteData : OCP.StdObjMgt.StdObjMgt_WriteData) -> None: 
        """
        Read persistent data from a file.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: 
        """
        Returns type descriptor of Standard_Transient class
        """
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class StdLPersistent_Function():
    def Import(self,theAttribute : OCP.TFunction.TFunction_Function) -> None: 
        """
        Import transient attribute from the persistent data.
        """
    def PChildren(self,arg0 : Any) -> None: 
        """
        Gets persistent child objects
        """
    def PName(self) -> str: 
        """
        Returns persistent type name
        """
    def Read(self,theReadData : OCP.StdObjMgt.StdObjMgt_ReadData) -> None: 
        """
        Read persistent data from a file.
        """
    def Write(self,theWriteData : OCP.StdObjMgt.StdObjMgt_WriteData) -> None: 
        """
        Write persistent data to a file.
        """
    def __init__(self) -> None: ...
    pass
class StdLPersistent_HArray1():
    def __init__(self) -> None: ...
    pass
class StdLPersistent_HArray1OfPersistent(OCP.Standard.Standard_Transient):
    def Array1(self) -> Any: ...
    def ChangeArray1(self) -> Any: ...
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theLower : int,theUpper : int) -> None: ...
    @overload
    def __init__(self,theLower : int,theUpper : int,theValue : OCP.StdObjMgt.StdObjMgt_Persistent) -> None: ...
    @overload
    def __init__(self,theBegin : OCP.StdObjMgt.StdObjMgt_Persistent,theLower : int,theUpper : int,arg3 : bool) -> None: ...
    @overload
    def __init__(self,theOther : Any) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class StdLPersistent_HArray2():
    def __init__(self) -> None: ...
    pass
class StdLPersistent_HArray2OfPersistent(OCP.Standard.Standard_Transient):
    def Array2(self) -> Any: ...
    def ChangeArray2(self) -> Any: ...
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    @overload
    def __init__(self,theRowLow : int,theRowUpp : int,theColLow : int,theColUpp : int) -> None: ...
    @overload
    def __init__(self,theRowLow : int,theRowUpp : int,theColLow : int,theColUpp : int,theValue : OCP.StdObjMgt.StdObjMgt_Persistent) -> None: ...
    @overload
    def __init__(self,theOther : Any) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class StdLPersistent_HString():
    def __init__(self) -> None: ...
    pass
class StdLPersistent_NamedData():
    def Import(self,theAttribute : OCP.TDataStd.TDataStd_NamedData) -> None: 
        """
        Import transient attribute from the persistent data.
        """
    def PChildren(self,arg0 : Any) -> None: 
        """
        Gets persistent child objects
        """
    def PName(self) -> str: 
        """
        Returns persistent type name
        """
    def Read(self,theReadData : OCP.StdObjMgt.StdObjMgt_ReadData) -> None: 
        """
        Read persistent data from a file.
        """
    def Write(self,theWriteData : OCP.StdObjMgt.StdObjMgt_WriteData) -> None: 
        """
        Write persistent data to a file.
        """
    def __init__(self) -> None: ...
    pass
class StdLPersistent_Real():
    def Import(self,theAttribute : OCP.TDataStd.TDataStd_Real) -> None: 
        """
        Import transient attribute from the persistent data.
        """
    def PChildren(self,arg0 : Any) -> None: 
        """
        Gets persistent child objects
        """
    def PName(self) -> str: 
        """
        Returns persistent type name
        """
    def Read(self,theReadData : OCP.StdObjMgt.StdObjMgt_ReadData) -> None: 
        """
        Read persistent data from a file.
        """
    def Write(self,theWriteData : OCP.StdObjMgt.StdObjMgt_WriteData) -> None: 
        """
        Write persistent data from a file.
        """
    def __init__(self) -> None: ...
    pass
class StdLPersistent_TreeNode():
    def CreateAttribute(self) -> OCP.TDF.TDF_Attribute: 
        """
        Create an empty transient attribute
        """
    def ImportAttribute(self) -> None: 
        """
        Import transient attribute from the persistent data.
        """
    def PChildren(self,arg0 : Any) -> None: 
        """
        Gets persistent child objects
        """
    def PName(self) -> str: 
        """
        Returns persistent type name
        """
    def Read(self,theReadData : OCP.StdObjMgt.StdObjMgt_ReadData) -> None: 
        """
        Read persistent data from a file.
        """
    def Write(self,theWriteData : OCP.StdObjMgt.StdObjMgt_WriteData) -> None: 
        """
        Write persistent data to a file.
        """
    def __init__(self) -> None: ...
    pass
class StdLPersistent_Value():
    def __init__(self) -> None: ...
    pass
class StdLPersistent_Variable():
    def Import(self,theAttribute : OCP.TDataStd.TDataStd_Variable) -> None: 
        """
        Import transient attribute from the persistent data.
        """
    def PChildren(self,theChildren : Any) -> None: 
        """
        Gets persistent child objects
        """
    def PName(self) -> str: 
        """
        Returns persistent type name
        """
    def Read(self,theReadData : OCP.StdObjMgt.StdObjMgt_ReadData) -> None: 
        """
        Read persistent data from a file.
        """
    def Write(self,theWriteData : OCP.StdObjMgt.StdObjMgt_WriteData) -> None: 
        """
        Write persistent data to a file.
        """
    def __init__(self) -> None: ...
    pass
class StdLPersistent_Void():
    def __init__(self) -> None: ...
    pass
class StdLPersistent_XLink():
    def Import(self,theAttribute : OCP.TDocStd.TDocStd_XLink) -> None: 
        """
        Import transient attribute from the persistent data.
        """
    def PChildren(self,theChildren : Any) -> None: 
        """
        Gets persistent child objects
        """
    def PName(self) -> str: 
        """
        Returns persistent type name
        """
    def Read(self,theReadData : OCP.StdObjMgt.StdObjMgt_ReadData) -> None: 
        """
        Read persistent data from a file.
        """
    def Write(self,theWriteData : OCP.StdObjMgt.StdObjMgt_WriteData) -> None: 
        """
        Write persistent data to a file.
        """
    def __init__(self) -> None: ...
    pass



import OCP.TCollection
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.Standard
import io
__all__  = [
"TCollection",
"TCollection_AsciiString",
"TCollection_ExtendedString",
"TCollection_HAsciiString",
"TCollection_HExtendedString",
"IsEqual"
]
class TCollection():
    """
    The package <TCollection> provides the services for the transient basic data structures.
    """
    @staticmethod
    def NextPrimeForMap_s(I : int) -> int: 
        """
        Returns a prime number greater than <I> suitable to dimension a Map. When <I> becomes great there is a limit on the result (today the limit is around 1 000 000). This is not a limit of the number of items but a limit in the number of buckets. i.e. there will be more collisions in the map.
        """
    def __init__(self) -> None: ...
    pass
class TCollection_AsciiString():
    """
    Class defines a variable-length sequence of 8-bit characters. Despite class name (kept for historical reasons), it is intended to store UTF-8 string, not just ASCII characters. However, multi-byte nature of UTF-8 is not considered by the following methods: - Method ::Length() return the number of bytes, not the number of Unicode symbols. - Methods taking/returning symbol index work with 8-bit code units, not true Unicode symbols, including ::Remove(), ::SetValue(), ::Value(), ::Search(), ::Trunc() and others. If application needs to process multi-byte Unicode symbols explicitly, NCollection_Utf8Iter class can be used for iterating through Unicode string (UTF-32 code unit will be returned for each position).
    """
    @overload
    def AssignCat(self,other : str) -> None: 
        """
        Appends <other> to me. This is an unary operator.

        Appends <other> to me. This is an unary operator.

        Appends <other> to me. This is an unary operator.

        Appends <other> to me. This is an unary operator. ex: aString += "Dummy" To catenate more than one CString, you must put a AsciiString before. Example: aString += "Hello " + "Dolly" IS NOT VALID ! But astring += anotherString + "Hello " + "Dolly" is valid.

        Appends <other> to me. This is an unary operator. Example: aString += anotherString
        """
    @overload
    def AssignCat(self,other : int) -> None: ...
    @overload
    def AssignCat(self,other : float) -> None: ...
    @overload
    def AssignCat(self,other : TCollection_AsciiString) -> None: ...
    def Capitalize(self) -> None: 
        """
        Converts the first character into its corresponding upper-case character and the other characters into lowercase Example: before me = "hellO " after me = "Hello "
        """
    @overload
    def Cat(self,other : str) -> TCollection_AsciiString: 
        """
        Appends <other> to me. Syntax: aString = aString + "Dummy" Example: aString contains "I say " aString = aString + "Hello " + "Dolly" gives "I say Hello Dolly" To catenate more than one CString, you must put a String before. So the following example is WRONG ! aString = "Hello " + "Dolly" THIS IS NOT ALLOWED This rule is applicable to AssignCat (operator +=) too.

        Appends <other> to me. Syntax: aString = aString + 15; Example: aString contains "I say " gives "I say 15" To catenate more than one CString, you must put a String before. So the following example is WRONG ! aString = "Hello " + "Dolly" THIS IS NOT ALLOWED This rule is applicable to AssignCat (operator +=) too.

        Appends <other> to me. Syntax: aString = aString + 15.15; Example: aString contains "I say " gives "I say 15.15" To catenate more than one CString, you must put a String before. So the following example is WRONG ! aString = "Hello " + "Dolly" THIS IS NOT ALLOWED This rule is applicable to AssignCat (operator +=) too.

        Appends <other> to me. Syntax: aString = aString + "Dummy" Example: aString contains "I say " aString = aString + "Hello " + "Dolly" gives "I say Hello Dolly" To catenate more than one CString, you must put a String before. So the following example is WRONG ! aString = "Hello " + "Dolly" THIS IS NOT ALLOWED This rule is applicable to AssignCat (operator +=) too.

        Appends <other> to me. Example: aString = aString + anotherString

        Appends <other> to me. Example: aString = aString + anotherString

        Appends <other> to me. Syntax: aString = aString + "Dummy" Example: aString contains "I say " aString = aString + "Hello " + "Dolly" gives "I say Hello Dolly" To catenate more than one CString, you must put a String before. So the following example is WRONG ! aString = "Hello " + "Dolly" THIS IS NOT ALLOWED This rule is applicable to AssignCat (operator +=) too.

        Appends <other> to me. Syntax: aString = aString + "Dummy" Example: aString contains "I say " aString = aString + "Hello " + "Dolly" gives "I say Hello Dolly" To catenate more than one CString, you must put a String before. So the following example is WRONG ! aString = "Hello " + "Dolly" THIS IS NOT ALLOWED This rule is applicable to AssignCat (operator +=) too.

        Appends <other> to me. Syntax: aString = aString + 15; Example: aString contains "I say " gives "I say 15" To catenate more than one CString, you must put a String before. So the following example is WRONG ! aString = "Hello " + "Dolly" THIS IS NOT ALLOWED This rule is applicable to AssignCat (operator +=) too.

        Appends <other> to me. Syntax: aString = aString + 15.15; Example: aString contains "I say " gives "I say 15.15" To catenate more than one CString, you must put a String before. So the following example is WRONG ! aString = "Hello " + "Dolly" THIS IS NOT ALLOWED This rule is applicable to AssignCat (operator +=) too.
        """
    @overload
    def Cat(self,other : int) -> TCollection_AsciiString: ...
    @overload
    def Cat(self,other : float) -> TCollection_AsciiString: ...
    @overload
    def Cat(self,other : TCollection_AsciiString) -> TCollection_AsciiString: ...
    def Center(self,Width : int,Filler : str) -> None: 
        """
        Modifies this ASCII string so that its length becomes equal to Width and the new characters are equal to Filler. New characters are added both at the beginning and at the end of this string. If Width is less than the length of this ASCII string, nothing happens. Example TCollection_AsciiString myAlphabet("abcdef"); myAlphabet.Center(9,' '); assert ( myAlphabet == " abcdef " );
        """
    def ChangeAll(self,aChar : str,NewChar : str,CaseSensitive : bool=True) -> None: 
        """
        Substitutes all the characters equal to aChar by NewChar in the AsciiString <me>. The substitution can be case sensitive. If you don't use default case sensitive, no matter whether aChar is uppercase or not. Example: me = "Histake" -> ChangeAll('H','M',Standard_True) gives me = "Mistake"
        """
    def Clear(self) -> None: 
        """
        Removes all characters contained in <me>. This produces an empty AsciiString.
        """
    @overload
    def Copy(self,fromwhere : str) -> None: 
        """
        Copy <fromwhere> to <me>. Used as operator = Example: aString = anotherCString;

        Copy <fromwhere> to <me>. Used as operator = Example: aString = anotherString;
        """
    @overload
    def Copy(self,fromwhere : TCollection_AsciiString) -> None: ...
    def EndsWith(self,theEndString : TCollection_AsciiString) -> bool: 
        """
        Determines whether the end of this string instance matches the specified string.
        """
    def FirstLocationInSet(self,Set : TCollection_AsciiString,FromIndex : int,ToIndex : int) -> int: 
        """
        Returns the index of the first character of <me> that is present in <Set>. The search begins to the index FromIndex and ends to the the index ToIndex. Returns zero if failure. Raises an exception if FromIndex or ToIndex is out of range. Example: before me = "aabAcAa", S = "Aa", FromIndex = 1, Toindex = 7 after me = "aabAcAa" returns 1
        """
    def FirstLocationNotInSet(self,Set : TCollection_AsciiString,FromIndex : int,ToIndex : int) -> int: 
        """
        Returns the index of the first character of <me> that is not present in the set <Set>. The search begins to the index FromIndex and ends to the the index ToIndex in <me>. Returns zero if failure. Raises an exception if FromIndex or ToIndex is out of range. Example: before me = "aabAcAa", S = "Aa", FromIndex = 1, Toindex = 7 after me = "aabAcAa" returns 3
        """
    def HashCode(self) -> int: 
        """
        Computes a hash code for the given ASCII string Returns the same integer value as the hash function for TCollection_ExtendedString

        Computes a hash code for the given ASCII string Returns the same integer value as the hash function for TCollection_ExtendedString
        """
    @overload
    def Insert(self,where : int,what : str) -> None: 
        """
        Inserts a Character at position <where>. Example: aString contains "hy not ?" aString.Insert(1,'W'); gives "Why not ?" aString contains "Wh" aString.Insert(3,'y'); gives "Why" aString contains "Way" aString.Insert(2,'h'); gives "Why"

        Inserts a CString at position <where>. Example: aString contains "O more" aString.Insert(2,"nce"); gives "Once more"

        Inserts a AsciiString at position <where>.
        """
    @overload
    def Insert(self,where : int,what : TCollection_AsciiString) -> None: ...
    def InsertAfter(self,Index : int,other : TCollection_AsciiString) -> None: 
        """
        Pushing a string after a specific index in the string <me>. Raises an exception if Index is out of bounds. - less than 0 (InsertAfter), or less than 1 (InsertBefore), or - greater than the number of characters in this ASCII string. Example: before me = "cde" , Index = 0 , other = "ab" after me = "abcde" , other = "ab"
        """
    def InsertBefore(self,Index : int,other : TCollection_AsciiString) -> None: 
        """
        Pushing a string before a specific index in the string <me>. Raises an exception if Index is out of bounds. - less than 0 (InsertAfter), or less than 1 (InsertBefore), or - greater than the number of characters in this ASCII string. Example: before me = "cde" , Index = 1 , other = "ab" after me = "abcde" , other = "ab"
        """
    def IntegerValue(self) -> int: 
        """
        Converts a AsciiString containing a numeric expression to an Integer. Example: "215" returns 215.
        """
    def IsAscii(self) -> bool: 
        """
        Returns True if the AsciiString contains only ASCII characters between ' ' and '~'. This means no control character and no extended ASCII code.
        """
    @overload
    def IsDifferent(self,other : str) -> bool: 
        """
        Returns true if there are differences between the characters in this ASCII string and ASCII string other. Note that this method is an alias of operator !=

        Returns true if there are differences between the characters in this ASCII string and ASCII string other. Note that this method is an alias of operator !=
        """
    @overload
    def IsDifferent(self,other : TCollection_AsciiString) -> bool: ...
    def IsEmpty(self) -> bool: 
        """
        Returns True if the string <me> contains zero character.
        """
    @overload
    def IsEqual(self,other : str) -> bool: 
        """
        Returns true if the characters in this ASCII string are identical to the characters in ASCII string other. Note that this method is an alias of operator ==.

        Returns true if the characters in this ASCII string are identical to the characters in ASCII string other. Note that this method is an alias of operator ==.
        """
    @overload
    def IsEqual(self,other : TCollection_AsciiString) -> bool: ...
    @staticmethod
    @overload
    def IsEqual_s(string1 : TCollection_AsciiString,string2 : TCollection_AsciiString) -> bool: 
        """
        Returns True when the two strings are the same. (Just for HashCode for AsciiString)

        Returns True when the two strings are the same. (Just for HashCode for AsciiString)
        """
    @staticmethod
    @overload
    def IsEqual_s(string1 : TCollection_AsciiString,string2 : str) -> bool: ...
    @overload
    def IsGreater(self,other : str) -> bool: 
        """
        Returns TRUE if <me> is 'ASCII' greater than <other>.

        Returns TRUE if <me> is 'ASCII' greater than <other>.
        """
    @overload
    def IsGreater(self,other : TCollection_AsciiString) -> bool: ...
    def IsIntegerValue(self) -> bool: 
        """
        Returns True if the AsciiString contains an integer value. Note: an integer value is considered to be a real value as well.
        """
    @overload
    def IsLess(self,other : str) -> bool: 
        """
        Returns TRUE if <me> is 'ASCII' less than <other>.

        Returns TRUE if <me> is 'ASCII' less than <other>.
        """
    @overload
    def IsLess(self,other : TCollection_AsciiString) -> bool: ...
    def IsRealValue(self,theToCheckFull : bool=False) -> bool: 
        """
        Returns True if the AsciiString starts with some characters that can be interpreted as integer or real value.
        """
    @staticmethod
    def IsSameString_s(theString1 : TCollection_AsciiString,theString2 : TCollection_AsciiString,theIsCaseSensitive : bool) -> bool: 
        """
        Returns True if the strings contain same characters.
        """
    def LeftAdjust(self) -> None: 
        """
        Removes all space characters in the beginning of the string.
        """
    def LeftJustify(self,Width : int,Filler : str) -> None: 
        """
        left justify Length becomes equal to Width and the new characters are equal to Filler. If Width < Length nothing happens. Raises an exception if Width is less than zero. Example: before me = "abcdef" , Width = 9 , Filler = ' ' after me = "abcdef "
        """
    def Length(self) -> int: 
        """
        Returns number of characters in <me>. This is the same functionality as 'strlen' in C. Example TCollection_AsciiString myAlphabet("abcdef"); assert ( myAlphabet.Length() == 6 ); - 1 is the position of the first character in this string. - The length of this string gives the position of its last character. - Positions less than or equal to zero, or greater than the length of this string are invalid in functions which identify a character of this string by its position.

        Returns number of characters in <me>. This is the same functionality as 'strlen' in C. Example TCollection_AsciiString myAlphabet("abcdef"); assert ( myAlphabet.Length() == 6 ); - 1 is the position of the first character in this string. - The length of this string gives the position of its last character. - Positions less than or equal to zero, or greater than the length of this string are invalid in functions which identify a character of this string by its position.
        """
    @overload
    def Location(self,other : TCollection_AsciiString,FromIndex : int,ToIndex : int) -> int: 
        """
        Returns an index in the string <me> of the first occurrence of the string S in the string <me> from the starting index FromIndex to the ending index ToIndex returns zero if failure Raises an exception if FromIndex or ToIndex is out of range. Example: before me = "aabAaAa", S = "Aa", FromIndex = 1, ToIndex = 7 after me = "aabAaAa" returns 4

        Returns the index of the nth occurrence of the character C in the string <me> from the starting index FromIndex to the ending index ToIndex. Returns zero if failure. Raises an exception if FromIndex or ToIndex is out of range. Example: before me = "aabAa", N = 3, C = 'a', FromIndex = 1, ToIndex = 5 after me = "aabAa" returns 5
        """
    @overload
    def Location(self,N : int,C : str,FromIndex : int,ToIndex : int) -> int: ...
    def LowerCase(self) -> None: 
        """
        Converts <me> to its lower-case equivalent. Example TCollection_AsciiString myString("Hello Dolly"); myString.UpperCase(); assert ( myString == "HELLO DOLLY" ); myString.LowerCase(); assert ( myString == "hello dolly" );
        """
    def Prepend(self,other : TCollection_AsciiString) -> None: 
        """
        Inserts the string other at the beginning of this ASCII string. Example TCollection_AsciiString myAlphabet("cde"); TCollection_AsciiString myBegin("ab"); myAlphabet.Prepend(myBegin); assert ( myAlphabet == "abcde" );
        """
    def Print(self,astream : io.BytesIO) -> None: 
        """
        Displays <me> on a stream.
        """
    def Read(self,astream : io.BytesIO) -> None: 
        """
        Read <me> from a stream.
        """
    def RealValue(self) -> float: 
        """
        Converts an AsciiString containing a numeric expression. to a Real. Example: ex: "215" returns 215.0. ex: "3.14159267" returns 3.14159267.
        """
    def Remove(self,where : int,ahowmany : int=1) -> None: 
        """
        Erases <ahowmany> characters from position <where>, <where> included. Example: aString contains "Hello" aString.Remove(2,2) erases 2 characters from position 2 This gives "Hlo".
        """
    @overload
    def RemoveAll(self,C : str,CaseSensitive : bool) -> None: 
        """
        Remove all the occurrences of the character C in the string. Example: before me = "HellLLo", C = 'L' , CaseSensitive = True after me = "Hello"

        Removes every <what> characters from <me>.
        """
    @overload
    def RemoveAll(self,what : str) -> None: ...
    def RightAdjust(self) -> None: 
        """
        Removes all space characters at the end of the string.
        """
    def RightJustify(self,Width : int,Filler : str) -> None: 
        """
        Right justify. Length becomes equal to Width and the new characters are equal to Filler. if Width < Length nothing happens. Raises an exception if Width is less than zero. Example: before me = "abcdef" , Width = 9 , Filler = ' ' after me = " abcdef"
        """
    @overload
    def Search(self,what : str) -> int: 
        """
        Searches a CString in <me> from the beginning and returns position of first item <what> matching. it returns -1 if not found. Example: aString contains "Sample single test" aString.Search("le") returns 5

        Searches an AsciiString in <me> from the beginning and returns position of first item <what> matching. It returns -1 if not found.
        """
    @overload
    def Search(self,what : TCollection_AsciiString) -> int: ...
    @overload
    def SearchFromEnd(self,what : str) -> int: 
        """
        Searches a CString in a AsciiString from the end and returns position of first item <what> matching. It returns -1 if not found. Example: aString contains "Sample single test" aString.SearchFromEnd("le") returns 12

        Searches a AsciiString in another AsciiString from the end and returns position of first item <what> matching. It returns -1 if not found.
        """
    @overload
    def SearchFromEnd(self,what : TCollection_AsciiString) -> int: ...
    @overload
    def SetValue(self,where : int,what : str) -> None: 
        """
        Replaces one character in the AsciiString at position <where>. If <where> is less than zero or greater than the length of <me> an exception is raised. Example: aString contains "Garbake" astring.Replace(6,'g') gives <me> = "Garbage"

        Replaces a part of <me> by a CString. If <where> is less than zero or greater than the length of <me> an exception is raised. Example: aString contains "abcde" aString.SetValue(4,"1234567") gives <me> = "abc1234567"

        Replaces a part of <me> by another AsciiString.
        """
    @overload
    def SetValue(self,where : int,what : TCollection_AsciiString) -> None: ...
    def Split(self,where : int) -> TCollection_AsciiString: 
        """
        Splits a AsciiString into two sub-strings. Example: aString contains "abcdefg" aString.Split(3) gives <me> = "abc" and returns "defg"
        """
    def StartsWith(self,theStartString : TCollection_AsciiString) -> bool: 
        """
        Determines whether the beginning of this string instance matches the specified string.
        """
    def SubString(self,FromIndex : int,ToIndex : int) -> TCollection_AsciiString: 
        """
        Creation of a sub-string of the string <me>. The sub-string starts to the index Fromindex and ends to the index ToIndex. Raises an exception if ToIndex or FromIndex is out of bounds Example: before me = "abcdefg", ToIndex=3, FromIndex=6 after me = "abcdefg" returns "cdef"

        Creation of a sub-string of the string <me>. The sub-string starts to the index Fromindex and ends to the index ToIndex. Raises an exception if ToIndex or FromIndex is out of bounds Example: before me = "abcdefg", ToIndex=3, FromIndex=6 after me = "abcdefg" returns "cdef"
        """
    def Swap(self,theOther : TCollection_AsciiString) -> None: 
        """
        Exchange the data of two strings (without reallocating memory).
        """
    def ToCString(self) -> str: 
        """
        Returns pointer to AsciiString (char *). This is useful for some casual manipulations. Warning: Because this "char *" is 'const', you can't modify its contents.

        Returns pointer to AsciiString (char *). This is useful for some casual manipulations. Warning: Because this "char *" is 'const', you can't modify its contents.
        """
    def Token(self,separators : str=' \t',whichone : int=1) -> TCollection_AsciiString: 
        """
        Extracts <whichone> token from <me>. By default, the <separators> is set to space and tabulation. By default, the token extracted is the first one (whichone = 1). <separators> contains all separators you need. If no token indexed by <whichone> is found, it returns empty AsciiString. Example: aString contains "This is a message" aString.Token() returns "This" aString.Token(" ",4) returns "message" aString.Token(" ",2) returns "is" aString.Token(" ",9) returns "" Other separators than space character and tabulation are allowed : aString contains "1234; test:message , value" aString.Token("; :,",4) returns "value" aString.Token("; :,",2) returns "test"
        """
    def Trunc(self,ahowmany : int) -> None: 
        """
        Truncates <me> to <ahowmany> characters. Example: me = "Hello Dolly" -> Trunc(3) -> me = "Hel"
        """
    def UpperCase(self) -> None: 
        """
        Converts <me> to its upper-case equivalent.
        """
    def UsefullLength(self) -> int: 
        """
        Length of the string ignoring all spaces (' ') and the control character at the end.
        """
    def Value(self,where : int) -> str: 
        """
        Returns character at position <where> in <me>. If <where> is less than zero or greater than the length of <me>, an exception is raised. Example: aString contains "Hello" aString.Value(2) returns 'e'
        """
    @overload
    def __add__(self,other : str) -> TCollection_AsciiString: ...
    @overload
    def __add__(self,other : int) -> TCollection_AsciiString: ...
    @overload
    def __add__(self,other : float) -> TCollection_AsciiString: ...
    @overload
    def __add__(self,other : TCollection_AsciiString) -> TCollection_AsciiString: ...
    @overload
    def __iadd__(self,other : str) -> None: ...
    @overload
    def __iadd__(self,other : int) -> None: ...
    @overload
    def __iadd__(self,other : float) -> None: ...
    @overload
    def __iadd__(self,other : TCollection_AsciiString) -> None: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,message : str) -> None: ...
    @overload
    def __init__(self,message : str,aLen : int) -> None: ...
    @overload
    def __init__(self,aChar : str) -> None: ...
    @overload
    def __init__(self,length : int,filler : str) -> None: ...
    @overload
    def __init__(self,value : int) -> None: ...
    @overload
    def __init__(self,value : float) -> None: ...
    @overload
    def __init__(self,astring : TCollection_AsciiString) -> None: ...
    @overload
    def __init__(self,astring : TCollection_AsciiString,message : str) -> None: ...
    @overload
    def __init__(self,astring : TCollection_AsciiString,message : TCollection_AsciiString) -> None: ...
    @overload
    def __init__(self,astring : TCollection_ExtendedString,replaceNonAscii : str='\x00') -> None: ...
    @overload
    def __init__(self,theStringUtf : str) -> None: ...
    @overload
    def __init__(self,arg0 : str) -> None: ...
    pass
class TCollection_ExtendedString():
    """
    A variable-length sequence of "extended" (UNICODE) characters (16-bit character type). It provides editing operations with built-in memory management to make ExtendedString objects easier to use than ordinary extended character arrays. ExtendedString objects follow "value semantics", that is, they are the actual strings, not handles to strings, and are copied through assignment. You may use HExtendedString objects to get handles to strings.
    """
    @overload
    def AssignCat(self,other : TCollection_ExtendedString) -> None: 
        """
        Appends the other extended string to this extended string. Note that this method is an alias of operator +=. Example: aString += anotherString

        Appends the utf16 char to this extended string.
        """
    @overload
    def AssignCat(self,theChar : str) -> None: ...
    def Cat(self,other : TCollection_ExtendedString) -> TCollection_ExtendedString: 
        """
        Appends <other> to me.
        """
    def ChangeAll(self,aChar : str,NewChar : str) -> None: 
        """
        Substitutes all the characters equal to aChar by NewChar in the ExtendedString <me>. The substitution can be case sensitive. If you don't use default case sensitive, no matter whether aChar is uppercase or not.
        """
    def Clear(self) -> None: 
        """
        Removes all characters contained in <me>. This produces an empty ExtendedString.
        """
    def Copy(self,fromwhere : TCollection_ExtendedString) -> None: 
        """
        Copy <fromwhere> to <me>. Used as operator =
        """
    def EndsWith(self,theEndString : TCollection_ExtendedString) -> bool: 
        """
        Determines whether the end of this string instance matches the specified string.
        """
    def HashCode(self) -> int: 
        """
        Returns a hashed value for the extended string. Note: if string is ASCII, the computed value is the same as the value computed with the HashCode function on a TCollection_AsciiString string composed with equivalent ASCII characters.
        """
    @overload
    def Insert(self,where : int,what : str) -> None: 
        """
        Insert a Character at position <where>.

        Insert a ExtendedString at position <where>.
        """
    @overload
    def Insert(self,where : int,what : TCollection_ExtendedString) -> None: ...
    def IsAscii(self) -> bool: 
        """
        Returns True if the ExtendedString contains only "Ascii Range" characters .
        """
    @overload
    def IsDifferent(self,other : str) -> bool: 
        """
        Returns true if there are differences between the characters in this extended string and the other extended string. Note that this method is an alias of operator !=.

        Returns true if there are differences between the characters in this extended string and the other extended string. Note that this method is an alias of operator !=.
        """
    @overload
    def IsDifferent(self,other : TCollection_ExtendedString) -> bool: ...
    def IsEmpty(self) -> bool: 
        """
        Returns True if this string contains no characters.
        """
    @overload
    def IsEqual(self,other : str) -> bool: 
        """
        Returns true if the characters in this extended string are identical to the characters in the other extended string. Note that this method is an alias of operator ==

        Returns true if the characters in this extended string are identical to the characters in the other extended string. Note that this method is an alias of operator ==
        """
    @overload
    def IsEqual(self,other : TCollection_ExtendedString) -> bool: ...
    @staticmethod
    def IsEqual_s(theString1 : TCollection_ExtendedString,theString2 : TCollection_ExtendedString) -> bool: 
        """
        Returns true if the characters in this extended string are identical to the characters in the other extended string. Note that this method is an alias of operator ==.
        """
    @overload
    def IsGreater(self,other : str) -> bool: 
        """
        Returns TRUE if <me> is greater than <other>.

        Returns TRUE if <me> is greater than <other>.
        """
    @overload
    def IsGreater(self,other : TCollection_ExtendedString) -> bool: ...
    @overload
    def IsLess(self,other : str) -> bool: 
        """
        Returns TRUE if <me> is less than <other>.

        Returns TRUE if <me> is less than <other>.
        """
    @overload
    def IsLess(self,other : TCollection_ExtendedString) -> bool: ...
    def Length(self) -> int: 
        """
        Returns the number of 16-bit code units (might be greater than number of Unicode symbols if string contains surrogate pairs).
        """
    def LengthOfCString(self) -> int: 
        """
        Returns expected CString length in UTF8 coding. It can be used for memory calculation before converting to CString containing symbols in UTF8 coding.
        """
    def Print(self,astream : io.BytesIO) -> None: 
        """
        Displays <me> .
        """
    def Remove(self,where : int,ahowmany : int=1) -> None: 
        """
        Erases <ahowmany> characters from position <where>,<where> included.
        """
    def RemoveAll(self,what : str) -> None: 
        """
        Removes every <what> characters from <me>.
        """
    def Search(self,what : TCollection_ExtendedString) -> int: 
        """
        Searches a ExtendedString in <me> from the beginning and returns position of first item <what> matching. it returns -1 if not found.
        """
    def SearchFromEnd(self,what : TCollection_ExtendedString) -> int: 
        """
        Searches a ExtendedString in another ExtendedString from the end and returns position of first item <what> matching. it returns -1 if not found.
        """
    @overload
    def SetValue(self,where : int,what : str) -> None: 
        """
        Replaces one character in the ExtendedString at position <where>. If <where> is less than zero or greater than the length of <me> an exception is raised.

        Replaces a part of <me> by another ExtendedString see above.
        """
    @overload
    def SetValue(self,where : int,what : TCollection_ExtendedString) -> None: ...
    def Split(self,where : int) -> TCollection_ExtendedString: 
        """
        Splits this extended string into two sub-strings at position where. - The second sub-string (from position where + 1 of this string to the end) is returned in a new extended string. - this extended string is modified: its last characters are removed, it becomes equal to the first sub-string (from the first character to position where). Example: aString contains "abcdefg" aString.Split(3) gives <me> = "abc" and returns "defg"
        """
    def StartsWith(self,theStartString : TCollection_ExtendedString) -> bool: 
        """
        Determines whether the beginning of this string instance matches the specified string.
        """
    def Swap(self,theOther : TCollection_ExtendedString) -> None: 
        """
        Exchange the data of two strings (without reallocating memory).
        """
    def ToExtString(self) -> str: 
        """
        Returns pointer to ExtString
        """
    def Token(self,separators : str,whichone : int=1) -> TCollection_ExtendedString: 
        """
        Extracts <whichone> token from <me>. By default, the <separators> is set to space and tabulation. By default, the token extracted is the first one (whichone = 1). <separators> contains all separators you need. If no token indexed by <whichone> is found, it returns an empty AsciiString. Example: aString contains "This is a message" aString.Token() returns "This" aString.Token(" ",4) returns "message" aString.Token(" ",2) returns "is" aString.Token(" ",9) returns "" Other separators than space character and tabulation are allowed : aString contains "1234; test:message , value" aString.Token("; :,",4) returns "value" aString.Token("; :,",2) returns "test"
        """
    def Trunc(self,ahowmany : int) -> None: 
        """
        Truncates <me> to <ahowmany> characters. Example: me = "Hello Dolly" -> Trunc(3) -> me = "Hel" Exceptions Standard_OutOfRange if ahowmany is greater than the length of this string.
        """
    def Value(self,where : int) -> str: 
        """
        Returns character at position <where> in <me>. If <where> is less than zero or greater than the length of <me>, an exception is raised. Example: aString contains "Hello" aString.Value(2) returns 'e' Exceptions Standard_OutOfRange if where lies outside the bounds of this extended string.
        """
    def __add__(self,other : TCollection_ExtendedString) -> TCollection_ExtendedString: ...
    def __iadd__(self,other : TCollection_ExtendedString) -> None: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,astring : str,isMultiByte : bool=False) -> None: ...
    @overload
    def __init__(self,astring : str) -> None: ...
    @overload
    def __init__(self,theStringUtf : str) -> None: ...
    @overload
    def __init__(self,aChar : str) -> None: ...
    @overload
    def __init__(self,length : int,filler : str) -> None: ...
    @overload
    def __init__(self,value : int) -> None: ...
    @overload
    def __init__(self,value : float) -> None: ...
    @overload
    def __init__(self,astring : TCollection_ExtendedString) -> None: ...
    @overload
    def __init__(self,astring : TCollection_AsciiString,isMultiByte : bool=True) -> None: ...
    pass
class TCollection_HAsciiString(OCP.Standard.Standard_Transient):
    """
    A variable-length sequence of ASCII characters (normal 8-bit character type). It provides editing operations with built-in memory management to make HAsciiString objects easier to use than ordinary character arrays. HAsciiString objects are handles to strings. - HAsciiString strings may be shared by several objects. - You may use an AsciiString object to get the actual string. Note: HAsciiString objects use an AsciiString string as a field.A variable-length sequence of ASCII characters (normal 8-bit character type). It provides editing operations with built-in memory management to make HAsciiString objects easier to use than ordinary character arrays. HAsciiString objects are handles to strings. - HAsciiString strings may be shared by several objects. - You may use an AsciiString object to get the actual string. Note: HAsciiString objects use an AsciiString string as a field.A variable-length sequence of ASCII characters (normal 8-bit character type). It provides editing operations with built-in memory management to make HAsciiString objects easier to use than ordinary character arrays. HAsciiString objects are handles to strings. - HAsciiString strings may be shared by several objects. - You may use an AsciiString object to get the actual string. Note: HAsciiString objects use an AsciiString string as a field.
    """
    @overload
    def AssignCat(self,other : str) -> None: 
        """
        Appends <other> to me.

        Appends <other> to me. Example: aString = aString + anotherString

        Appends <other> to me.

        Appends <other> to me. Example: aString = aString + anotherString
        """
    @overload
    def AssignCat(self,other : TCollection_HAsciiString) -> None: ...
    def Capitalize(self) -> None: 
        """
        Converts the first character into its corresponding upper-case character and the other characters into lowercase. Example: before me = "hellO " after me = "Hello "
        """
    @overload
    def Cat(self,other : str) -> TCollection_HAsciiString: 
        """
        Creates a new string by concatenation of this ASCII string and the other ASCII string. Example: aString = aString + anotherString aString = aString + "Dummy" aString contains "I say " aString = aString + "Hello " + "Dolly" gives "I say Hello Dolly" Warning: To catenate more than one CString, you must put a String before. So the following example is WRONG ! aString = "Hello " + "Dolly" THIS IS NOT ALLOWED This rule is applicable to AssignCat (operator +=) too.

        Creates a new string by concatenation of this ASCII string and the other ASCII string. Example: aString = aString + anotherString
        """
    @overload
    def Cat(self,other : TCollection_HAsciiString) -> TCollection_HAsciiString: ...
    def Center(self,Width : int,Filler : str) -> None: 
        """
        Modifies this ASCII string so that its length becomes equal to Width and the new characters are equal to Filler. New characters are added both at the beginning and at the end of this string. If Width is less than the length of this ASCII string, nothing happens. Example Handle(TCollection_HAsciiString) myAlphabet = new TCollection_HAsciiString ("abcdef"); myAlphabet->Center(9,' '); assert ( !strcmp( myAlphabet->ToCString(), " abcdef ") );
        """
    def ChangeAll(self,aChar : str,NewChar : str,CaseSensitive : bool=True) -> None: 
        """
        Replaces all characters equal to aChar by NewChar in this ASCII string. The substitution is case sensitive if CaseSensitive is true (default value). If you do not use the default case sensitive option, it does not matter whether aChar is upper-case or not. Example Handle(TCollection_HAsciiString) myMistake = new TCollection_HAsciiString ("Hather"); myMistake->ChangeAll('H','F'); assert ( !strcmp( myMistake->ToCString(), "Father") );
        """
    def Clear(self) -> None: 
        """
        Removes all characters contained in <me>. This produces an empty HAsciiString.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def FirstLocationInSet(self,Set : TCollection_HAsciiString,FromIndex : int,ToIndex : int) -> int: 
        """
        Returns the index of the first character of <me> that is present in <Set>. The search begins to the index FromIndex and ends to the the index ToIndex. Returns zero if failure. Raises an exception if FromIndex or ToIndex is out of range Example: before me = "aabAcAa", S = "Aa", FromIndex = 1, Toindex = 7 after me = "aabAcAa" returns 1
        """
    def FirstLocationNotInSet(self,Set : TCollection_HAsciiString,FromIndex : int,ToIndex : int) -> int: 
        """
        Returns the index of the first character of <me> that is not present in the set <Set>. The search begins to the index FromIndex and ends to the the index ToIndex in <me>. Returns zero if failure. Raises an exception if FromIndex or ToIndex is out of range. Example: before me = "aabAcAa", S = "Aa", FromIndex = 1, Toindex = 7 after me = "aabAcAa" returns 3
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def Insert(self,where : int,what : str) -> None: 
        """
        Insert a Character at position <where>. Example: aString contains "hy not ?" aString.Insert(1,'W'); gives "Why not ?" aString contains "Wh" aString.Insert(3,'y'); gives "Why" aString contains "Way" aString.Insert(2,'h'); gives "Why"

        Insert a HAsciiString at position <where>.

        Insert a HAsciiString at position <where>.
        """
    @overload
    def Insert(self,where : int,what : TCollection_HAsciiString) -> None: ...
    def InsertAfter(self,Index : int,other : TCollection_HAsciiString) -> None: 
        """
        Inserts the other ASCII string a after a specific index in the string <me> Example: before me = "cde" , Index = 0 , other = "ab" after me = "abcde" , other = "ab"
        """
    def InsertBefore(self,Index : int,other : TCollection_HAsciiString) -> None: 
        """
        Inserts the other ASCII string a before a specific index in the string <me> Raises an exception if Index is out of bounds Example: before me = "cde" , Index = 1 , other = "ab" after me = "abcde" , other = "ab"
        """
    def IntegerValue(self) -> int: 
        """
        Converts a HAsciiString containing a numeric expression to an Integer. Example: "215" returns 215.
        """
    def IsAscii(self) -> bool: 
        """
        Returns True if the string contains only ASCII characters between ' ' and '~'. This means no control character and no extended ASCII code.
        """
    def IsDifferent(self,S : TCollection_HAsciiString) -> bool: 
        """
        Returns True if the string S not contains same characters than the string <me>.
        """
    def IsEmpty(self) -> bool: 
        """
        Returns True if the string <me> contains zero character
        """
    def IsGreater(self,other : TCollection_HAsciiString) -> bool: 
        """
        Returns TRUE if <me> is 'ASCII' greater than <other>.
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    def IsIntegerValue(self) -> bool: 
        """
        Returns True if the string contains an integer value.
        """
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def IsLess(self,other : TCollection_HAsciiString) -> bool: 
        """
        Returns TRUE if <me> is 'ASCII' less than <other>.
        """
    def IsRealValue(self) -> bool: 
        """
        Returns True if the string contains a real value.
        """
    def IsSameState(self,other : TCollection_HAsciiString) -> bool: ...
    @overload
    def IsSameString(self,S : TCollection_HAsciiString) -> bool: 
        """
        Returns True if the string S contains same characters than the string <me>.

        Returns True if the string S contains same characters than the string <me>.
        """
    @overload
    def IsSameString(self,S : TCollection_HAsciiString,CaseSensitive : bool) -> bool: ...
    def LeftAdjust(self) -> None: 
        """
        Removes all space characters in the beginning of the string
        """
    def LeftJustify(self,Width : int,Filler : str) -> None: 
        """
        Left justify. Length becomes equal to Width and the new characters are equal to Filler if Width < Length nothing happens Raises an exception if Width is less than zero Example: before me = "abcdef" , Width = 9 , Filler = ' ' after me = "abcdef "
        """
    def Length(self) -> int: 
        """
        Returns number of characters in <me>. This is the same functionality as 'strlen' in C.

        Returns number of characters in <me>. This is the same functionality as 'strlen' in C.
        """
    @overload
    def Location(self,other : TCollection_HAsciiString,FromIndex : int,ToIndex : int) -> int: 
        """
        returns an index in the string <me> of the first occurrence of the string S in the string <me> from the starting index FromIndex to the ending index ToIndex returns zero if failure Raises an exception if FromIndex or ToIndex is out of range. Example: before me = "aabAaAa", S = "Aa", FromIndex = 1, ToIndex = 7 after me = "aabAaAa" returns 4

        Returns the index of the nth occurrence of the character C in the string <me> from the starting index FromIndex to the ending index ToIndex. Returns zero if failure. Raises an exception if FromIndex or ToIndex is out of range Example: before me = "aabAa", N = 3, C = 'a', FromIndex = 1, ToIndex = 5 after me = "aabAa" returns 5
        """
    @overload
    def Location(self,N : int,C : str,FromIndex : int,ToIndex : int) -> int: ...
    def LowerCase(self) -> None: 
        """
        Converts <me> to its lower-case equivalent.
        """
    def Prepend(self,other : TCollection_HAsciiString) -> None: 
        """
        Inserts the other string at the beginning of the string <me> Example: before me = "cde" , S = "ab" after me = "abcde" , S = "ab"
        """
    def Print(self,astream : io.BytesIO) -> None: 
        """
        Prints this string on the stream <astream>.
        """
    def RealValue(self) -> float: 
        """
        Converts a string containing a numeric expression to a Real. Example: "215" returns 215.0. "3.14159267" returns 3.14159267.
        """
    def Remove(self,where : int,ahowmany : int=1) -> None: 
        """
        Erases <ahowmany> characters from position <where>, <where> included. Example: aString contains "Hello" aString.Erase(2,2) erases 2 characters from position 1 This gives "Hlo".
        """
    @overload
    def RemoveAll(self,C : str,CaseSensitive : bool) -> None: 
        """
        Remove all the occurrences of the character C in the string Example: before me = "HellLLo", C = 'L' , CaseSensitive = True after me = "Hello"

        Removes every <what> characters from <me>
        """
    @overload
    def RemoveAll(self,what : str) -> None: ...
    def RightAdjust(self) -> None: 
        """
        Removes all space characters at the end of the string.
        """
    def RightJustify(self,Width : int,Filler : str) -> None: 
        """
        Right justify. Length becomes equal to Width and the new characters are equal to Filler if Width < Length nothing happens Raises an exception if Width is less than zero Example: before me = "abcdef" , Width = 9 , Filler = ' ' after me = " abcdef"
        """
    @overload
    def Search(self,what : str) -> int: 
        """
        Searches a CString in <me> from the beginning and returns position of first item <what> matching. It returns -1 if not found. Example: aString contains "Sample single test" aString.Search("le") returns 5

        Searches a String in <me> from the beginning and returns position of first item <what> matching. it returns -1 if not found.
        """
    @overload
    def Search(self,what : TCollection_HAsciiString) -> int: ...
    @overload
    def SearchFromEnd(self,what : str) -> int: 
        """
        Searches a CString in a String from the end and returns position of first item <what> matching. It returns -1 if not found. Example: aString contains "Sample single test" aString.SearchFromEnd("le") returns 12

        Searches a HAsciiString in another HAsciiString from the end and returns position of first item <what> matching. It returns -1 if not found.
        """
    @overload
    def SearchFromEnd(self,what : TCollection_HAsciiString) -> int: ...
    @overload
    def SetValue(self,where : int,what : str) -> None: 
        """
        Replaces one character in the string at position <where>. If <where> is less than zero or greater than the length of <me> an exception is raised. Example: aString contains "Garbake" astring.Replace(6,'g') gives <me> = "Garbage"

        Replaces a part of <me> in the string at position <where>. If <where> is less than zero or greater than the length of <me> an exception is raised. Example: aString contains "Garbake" astring.Replace(6,'g') gives <me> = "Garbage"

        Replaces a part of <me> by another string.
        """
    @overload
    def SetValue(self,where : int,what : TCollection_HAsciiString) -> None: ...
    def Split(self,where : int) -> TCollection_HAsciiString: 
        """
        Splits a HAsciiString into two sub-strings. Example: aString contains "abcdefg" aString.Split(3) gives <me> = "abc" and returns "defg"
        """
    def String(self) -> TCollection_AsciiString: 
        """
        Returns the field myString.

        Returns the field myString.
        """
    def SubString(self,FromIndex : int,ToIndex : int) -> TCollection_HAsciiString: 
        """
        Creation of a sub-string of the string <me>. The sub-string starts to the index Fromindex and ends to the index ToIndex. Raises an exception if ToIndex or FromIndex is out of bounds Example: before me = "abcdefg", ToIndex=3, FromIndex=6 after me = "abcdefg" returns "cdef"
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def ToCString(self) -> str: 
        """
        Returns pointer to string (char *) This is useful for some casual manipulations Because this "char *" is 'const', you can't modify its contents.

        Returns pointer to string (char *) This is useful for some casual manipulations Because this "char *" is 'const', you can't modify its contents.
        """
    def Token(self,separators : str=' \t',whichone : int=1) -> TCollection_HAsciiString: 
        """
        Extracts <whichone> token from <me>. By default, the <separators> is set to space and tabulation. By default, the token extracted is the first one (whichone = 1). <separators> contains all separators you need. If no token indexed by <whichone> is found, it returns an empty String. Example: aString contains "This is a message" aString.Token() returns "This" aString.Token(" ",4) returns "message" aString.Token(" ",2) returns "is" aString.Token(" ",9) returns "" Other separators than space character and tabulation are allowed aString contains "1234; test:message , value" aString.Token("; :,",4) returns "value" aString.Token("; :,",2) returns "test"
        """
    def Trunc(self,ahowmany : int) -> None: 
        """
        Truncates <me> to <ahowmany> characters. Example: me = "Hello Dolly" -> Trunc(3) -> me = "Hel"
        """
    def UpperCase(self) -> None: 
        """
        Converts <me> to its upper-case equivalent.
        """
    def UsefullLength(self) -> int: 
        """
        Length of the string ignoring all spaces (' ') and the control character at the end.
        """
    def Value(self,where : int) -> str: 
        """
        Returns character at position <where> in <me>. If <where> is less than zero or greater than the length of <me>, an exception is raised. Example: aString contains "Hello" aString.Value(2) returns 'e'
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,message : str) -> None: ...
    @overload
    def __init__(self,aChar : str) -> None: ...
    @overload
    def __init__(self,length : int,filler : str) -> None: ...
    @overload
    def __init__(self,value : int) -> None: ...
    @overload
    def __init__(self,value : float) -> None: ...
    @overload
    def __init__(self,aString : TCollection_AsciiString) -> None: ...
    @overload
    def __init__(self,aString : TCollection_HAsciiString) -> None: ...
    @overload
    def __init__(self,aString : TCollection_HExtendedString,replaceNonAscii : str) -> None: ...
    @overload
    def __init__(self,arg0 : str) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class TCollection_HExtendedString(OCP.Standard.Standard_Transient):
    """
    A variable-length sequence of "extended" (UNICODE) characters (16-bit character type). It provides editing operations with built-in memory management to make ExtendedString objects easier to use than ordinary extended character arrays. HExtendedString objects are handles to strings. - HExtendedString strings may be shared by several objects. - You may use an ExtendedString object to get the actual string. Note: HExtendedString objects use an ExtendedString string as a field.A variable-length sequence of "extended" (UNICODE) characters (16-bit character type). It provides editing operations with built-in memory management to make ExtendedString objects easier to use than ordinary extended character arrays. HExtendedString objects are handles to strings. - HExtendedString strings may be shared by several objects. - You may use an ExtendedString object to get the actual string. Note: HExtendedString objects use an ExtendedString string as a field.A variable-length sequence of "extended" (UNICODE) characters (16-bit character type). It provides editing operations with built-in memory management to make ExtendedString objects easier to use than ordinary extended character arrays. HExtendedString objects are handles to strings. - HExtendedString strings may be shared by several objects. - You may use an ExtendedString object to get the actual string. Note: HExtendedString objects use an ExtendedString string as a field.
    """
    def AssignCat(self,other : TCollection_HExtendedString) -> None: 
        """
        Appends <other> to me.
        """
    def Cat(self,other : TCollection_HExtendedString) -> TCollection_HExtendedString: 
        """
        Returns a string appending <other> to me.
        """
    def ChangeAll(self,aChar : str,NewChar : str) -> None: 
        """
        Substitutes all the characters equal to aChar by NewChar in the string <me>.
        """
    def Clear(self) -> None: 
        """
        Removes all characters contained in <me>. This produces an empty ExtendedString.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def Insert(self,where : int,what : str) -> None: 
        """
        Insert a ExtCharacter at position <where>. Example: aString contains "hy not ?" aString.Insert(1,'W'); gives "Why not ?" aString contains "Wh" aString.Insert(3,'y'); gives "Why" aString contains "Way" aString.Insert(2,'h'); gives "Why"

        Insert a HExtendedString at position <where>.
        """
    @overload
    def Insert(self,where : int,what : TCollection_HExtendedString) -> None: ...
    def IsAscii(self) -> bool: 
        """
        Returns True if the string contains only "Ascii Range" characters
        """
    def IsEmpty(self) -> bool: 
        """
        Returns True if the string <me> contains zero character
        """
    def IsGreater(self,other : TCollection_HExtendedString) -> bool: 
        """
        Returns TRUE if <me> is greater than <other>.
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def IsLess(self,other : TCollection_HExtendedString) -> bool: 
        """
        Returns TRUE if <me> is less than <other>.
        """
    def IsSameState(self,other : TCollection_HExtendedString) -> bool: ...
    def Length(self) -> int: 
        """
        Returns number of characters in <me>. This is the same functionality as 'strlen' in C.
        """
    def Print(self,astream : io.BytesIO) -> None: 
        """
        Displays <me> .
        """
    def Remove(self,where : int,ahowmany : int=1) -> None: 
        """
        Erases <ahowmany> characters from position <where>, <where> included. Example: aString contains "Hello" aString.Erase(2,2) erases 2 characters from position 1 This gives "Hlo".
        """
    def RemoveAll(self,what : str) -> None: 
        """
        Removes every <what> characters from <me>.
        """
    def Search(self,what : TCollection_HExtendedString) -> int: 
        """
        Searches a String in <me> from the beginning and returns position of first item <what> matching. It returns -1 if not found.
        """
    def SearchFromEnd(self,what : TCollection_HExtendedString) -> int: 
        """
        Searches a ExtendedString in another ExtendedString from the end and returns position of first item <what> matching. It returns -1 if not found.
        """
    @overload
    def SetValue(self,where : int,what : str) -> None: 
        """
        Replaces one character in the string at position <where>. If <where> is less than zero or greater than the length of <me> an exception is raised. Example: aString contains "Garbake" astring.Replace(6,'g') gives <me> = "Garbage"

        Replaces a part of <me> by another string.
        """
    @overload
    def SetValue(self,where : int,what : TCollection_HExtendedString) -> None: ...
    def Split(self,where : int) -> TCollection_HExtendedString: 
        """
        Splits a ExtendedString into two sub-strings. Example: aString contains "abcdefg" aString.Split(3) gives <me> = "abc" and returns "defg"
        """
    def String(self) -> TCollection_ExtendedString: 
        """
        Returns the field myString
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def ToExtString(self) -> str: 
        """
        Returns pointer to ExtString
        """
    def Token(self,separators : str,whichone : int=1) -> TCollection_HExtendedString: 
        """
        Extracts <whichone> token from <me>. By default, the <separators> is set to space and tabulation. By default, the token extracted is the first one (whichone = 1). <separators> contains all separators you need. If no token indexed by <whichone> is found, it returns an empty String. Example: aString contains "This is a message" aString.Token() returns "This" aString.Token(" ",4) returns "message" aString.Token(" ",2) returns "is" aString.Token(" ",9) returns "" Other separators than space character and tabulation are allowed aString contains "1234; test:message , value" aString.Token("; :,",4) returns "value" aString.Token("; :,",2) returns "test"
        """
    def Trunc(self,ahowmany : int) -> None: 
        """
        Truncates <me> to <ahowmany> characters. Example: me = "Hello Dolly" -> Trunc(3) -> me = "Hel"
        """
    def Value(self,where : int) -> str: 
        """
        Returns ExtCharacter at position <where> in <me>. If <where> is less than zero or greater than the length of <me>, an exception is raised. Example: aString contains "Hello" aString.Value(2) returns 'e'
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,message : str) -> None: ...
    @overload
    def __init__(self,aChar : str) -> None: ...
    @overload
    def __init__(self,length : int,filler : str) -> None: ...
    @overload
    def __init__(self,aString : TCollection_ExtendedString) -> None: ...
    @overload
    def __init__(self,aString : TCollection_HAsciiString) -> None: ...
    @overload
    def __init__(self,aString : TCollection_HExtendedString) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
def IsEqual(string1 : TCollection_AsciiString,string2 : TCollection_AsciiString) -> bool:
    pass



import OCP.TopBas
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.TopAbs
import OCP.NCollection
__all__  = [
"TopBas_ListOfTestInterference",
"TopBas_TestInterference"
]
class TopBas_ListOfTestInterference(OCP.NCollection.NCollection_BaseList):
    """
    Purpose: Simple list to link items together keeping the first and the last one. Inherits BaseList, adding the data item to each node.
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    @overload
    def Append(self,theItem : TopBas_TestInterference) -> TopBas_TestInterference: 
        """
        Append one item at the end

        Append one item at the end and output iterator pointing at the appended item

        Append another list at the end. After this operation, theOther list will be cleared.
        """
    @overload
    def Append(self,theItem : TopBas_TestInterference,theIter : Any) -> None: ...
    @overload
    def Append(self,theOther : TopBas_ListOfTestInterference) -> None: ...
    def Assign(self,theOther : TopBas_ListOfTestInterference) -> TopBas_ListOfTestInterference: 
        """
        Replace this list by the items of another list (theOther parameter). This method does not change the internal allocator.
        """
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: 
        """
        Clear this list
        """
    def Extent(self) -> int: ...
    def First(self) -> TopBas_TestInterference: 
        """
        First item

        First item (non-const)
        """
    @overload
    def InsertAfter(self,theItem : TopBas_TestInterference,theIter : Any) -> TopBas_TestInterference: 
        """
        InsertAfter

        InsertAfter
        """
    @overload
    def InsertAfter(self,theOther : TopBas_ListOfTestInterference,theIter : Any) -> None: ...
    @overload
    def InsertBefore(self,theItem : TopBas_TestInterference,theIter : Any) -> TopBas_TestInterference: 
        """
        InsertBefore

        InsertBefore
        """
    @overload
    def InsertBefore(self,theOther : TopBas_ListOfTestInterference,theIter : Any) -> None: ...
    def IsEmpty(self) -> bool: ...
    def Last(self) -> TopBas_TestInterference: 
        """
        Last item

        Last item (non-const)
        """
    @overload
    def Prepend(self,theItem : TopBas_TestInterference) -> TopBas_TestInterference: 
        """
        Prepend one item at the beginning

        Prepend another list at the beginning
        """
    @overload
    def Prepend(self,theOther : TopBas_ListOfTestInterference) -> None: ...
    def Remove(self,theIter : Any) -> None: 
        """
        Remove item pointed by iterator theIter; theIter is then set to the next item
        """
    def RemoveFirst(self) -> None: 
        """
        RemoveFirst item
        """
    def Reverse(self) -> None: 
        """
        Reverse the list
        """
    def Size(self) -> int: 
        """
        Size - Number of items
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    @overload
    def __init__(self,theOther : TopBas_ListOfTestInterference) -> None: ...
    def __iter__(self) -> Iterator[TopBas_TestInterference]: ...
    def __len__(self) -> int: ...
    pass
class TopBas_TestInterference():
    @overload
    def Boundary(self,B : int) -> None: ...
    @overload
    def Boundary(self) -> int: ...
    @overload
    def BoundaryTransition(self,BTr : OCP.TopAbs.TopAbs_Orientation) -> None: ...
    @overload
    def BoundaryTransition(self) -> OCP.TopAbs.TopAbs_Orientation: ...
    @overload
    def Intersection(self,I : float) -> None: ...
    @overload
    def Intersection(self) -> float: ...
    @overload
    def Orientation(self,O : OCP.TopAbs.TopAbs_Orientation) -> None: ...
    @overload
    def Orientation(self) -> OCP.TopAbs.TopAbs_Orientation: ...
    @overload
    def Transition(self,Tr : OCP.TopAbs.TopAbs_Orientation) -> None: ...
    @overload
    def Transition(self) -> OCP.TopAbs.TopAbs_Orientation: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,Inters : float,Bound : int,Orient : OCP.TopAbs.TopAbs_Orientation,Trans : OCP.TopAbs.TopAbs_Orientation,BTrans : OCP.TopAbs.TopAbs_Orientation) -> None: ...
    @property
    def ChangeBoundary(self) -> int:
        """
        :type: int
        """
    @ChangeBoundary.setter
    def ChangeBoundary(self, arg1: int) -> None:
        pass
    @property
    def ChangeIntersection(self) -> float:
        """
        :type: float
        """
    @ChangeIntersection.setter
    def ChangeIntersection(self, arg1: float) -> None:
        pass
    pass
